# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/hive.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from ydb.core.protos import tablet_pb2 as ydb_dot_core_dot_protos_dot_tablet__pb2
from ydb.core.protos import subdomains_pb2 as ydb_dot_core_dot_protos_dot_subdomains__pb2
from ydb.core.protos import bind_channel_storage_pool_pb2 as ydb_dot_core_dot_protos_dot_bind__channel__storage__pool__pb2
from ydb.core.protos import follower_group_pb2 as ydb_dot_core_dot_protos_dot_follower__group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aydb/core/protos/hive.proto\x12\x0bNKikimrHive\x1a&library/cpp/actors/protos/actors.proto\x1a\x1aydb/core/protos/base.proto\x1a\x1cydb/core/protos/tablet.proto\x1a ydb/core/protos/subdomains.proto\x1a/ydb/core/protos/bind_channel_storage_pool.proto\x1a$ydb/core/protos/follower_group.proto\"\xad\x01\n\x0cTChannelInfo\x12\n\n\x02Id\x18\x01 \x01(\r\x12\x0c\n\x04Type\x18\x02 \x01(\r\x12\x37\n\x07History\x18\x03 \x03(\x0b\x32&.NKikimrHive.TChannelInfo.THistorySlot\x1aJ\n\x0cTHistorySlot\x12\x16\n\x0e\x46romGeneration\x18\x01 \x01(\r\x12\x0f\n\x07GroupID\x18\x02 \x01(\r\x12\x11\n\tTimestamp\x18\x03 \x01(\x04\"!\n\rTEvBootTablet\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\"S\n\x12TEvBootTabletReply\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x11\n\tStatusMsg\x18\x02 \x01(\t\"d\n\x0fTTabletCategory\x12\x18\n\x10TabletCategoryID\x18\x01 \x01(\x04\x12\x1c\n\x14MaxDisconnectTimeout\x18\x02 \x01(\x04\x12\x19\n\x11StickTogetherInDC\x18\x03 \x01(\x08\"B\n\x11TDataCentersGroup\x12\x19\n\rDataCenterNum\x18\x01 \x03(\x04\x42\x02\x18\x01\x12\x12\n\nDataCenter\x18\x02 \x03(\t\"S\n\x16TDataCentersPreference\x12\x39\n\x11\x44\x61taCentersGroups\x18\x01 \x03(\x0b\x32\x1e.NKikimrHive.TDataCentersGroup\"\xe4\x07\n\x0fTEvCreateTablet\x12\r\n\x05Owner\x18\x01 \x01(\x06\x12\x10\n\x08OwnerIdx\x18\x02 \x01(\x04\x12\x39\n\nTabletType\x18\x03 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\x1a\n\x12\x41ssignStateStorage\x18\x04 \x01(\r\x12\x16\n\x0e\x41llowedNodeIDs\x18\x07 \x03(\r\x12#\n\x17\x41llowedDataCenterNumIDs\x18\x0e \x03(\x04\x42\x02\x18\x01\x12\x34\n\x0eTabletCategory\x18\x10 \x01(\x0b\x32\x1c.NKikimrHive.TTabletCategory\x12\x33\n\x0e\x46ollowerGroups\x18\x11 \x03(\x0b\x32\x1b.NKikimrHive.TFollowerGroup\x12\x33\n\x0cObjectDomain\x18\x12 \x01(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\x12\x34\n\x0eTabletBootMode\x18\x13 \x01(\x0e\x32\x1c.NKikimrHive.ETabletBootMode\x12\x10\n\x08ObjectId\x18\x14 \x01(\x04\x12\x38\n\x0e\x42indedChannels\x18\x15 \x03(\x0b\x32 .NKikimrStoragePool.TChannelBind\x12\x10\n\x08TabletID\x18\x16 \x01(\x06\x12\x35\n\x0e\x41llowedDomains\x18\x17 \x03(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\x12\x42\n\x15\x44\x61taCentersPreference\x18\x18 \x01(\x0b\x32#.NKikimrHive.TDataCentersPreference\x12\x1a\n\x12\x41llowedDataCenters\x18\x19 \x03(\t\x12\x34\n\x0e\x42\x61lancerPolicy\x18\x1a \x01(\x0e\x32\x1c.NKikimrHive.EBalancerPolicy\x12\x1b\n\x0f\x43hannelsProfile\x18\x05 \x01(\rB\x02\x18\x01\x12\x11\n\x05\x46lags\x18\x06 \x01(\rB\x02\x18\x01\x12#\n\x17\x42ootTimeoutMilliSeconds\x18\x08 \x01(\rB\x02\x18\x01\x12\x1c\n\x10\x42ootAttemptLimit\x18\t \x01(\rB\x02\x18\x01\x12\x18\n\x06Weight\x18\n \x01(\x04:\x04\x31\x30\x30\x30\x42\x02\x18\x01\x12\x18\n\rFollowerCount\x18\x0b \x01(\r:\x01\x30\x12%\n\x16\x41llowFollowerPromotion\x18\x0c \x01(\x08:\x05\x66\x61lse\x12\'\n\x18\x43rossDataCenterFollowers\x18\r \x01(\x08:\x05\x66\x61lse\x12$\n\x1c\x43rossDataCenterFollowerCount\x18\x0f \x01(\r\"2\n\x0fTEvLookupTablet\x12\r\n\x05Owner\x18\x01 \x01(\x06\x12\x10\n\x08OwnerIdx\x18\x02 \x01(\x04\"\xeb\x01\n\x14TEvCreateTabletReply\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\r\n\x05Owner\x18\x02 \x01(\x06\x12\x10\n\x08OwnerIdx\x18\x03 \x01(\x04\x12\x10\n\x08TabletID\x18\x04 \x01(\x06\x12\x0e\n\x06Origin\x18\x05 \x01(\x06\x12.\n\x0b\x45rrorReason\x18\x06 \x01(\x0e\x32\x19.NKikimrHive.EErrorReason\x12\x34\n\x0e\x46orwardRequest\x18\x07 \x01(\x0b\x32\x1c.NKikimrHive.TForwardRequest\"W\n\x17TEvTabletCreationResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x10\n\x08TabletID\x18\x02 \x01(\x06\"P\n\rTEvStopTablet\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12-\n\rActorToNotify\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\"S\n\x13TEvStopTabletResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x10\n\x08TabletID\x18\x02 \x01(\x06\"U\n\x15TEvResumeTabletResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x10\n\x08TabletID\x18\x02 \x01(\x06\"=\n\x0fTChannelRequest\x12\n\n\x02Id\x18\x01 \x01(\r\x12\x0c\n\x04Type\x18\x02 \x01(\r\x12\x10\n\x08Locality\x18\x03 \x01(\r\"\x90\x01\n\x14TEvReconfigureTablet\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x10\n\x08\x41utoboot\x18\x02 \x01(\x08\x12$\n\x1c\x43hannelReconfigureGeneration\x18\x03 \x01(\r\x12.\n\x08\x43hannels\x18\x04 \x03(\x0b\x32\x1c.NKikimrHive.TChannelRequest\"\xa7\x01\n\x0eTEvAdoptTablet\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x11\n\tPrevOwner\x18\x02 \x01(\x06\x12\x14\n\x0cPrevOwnerIdx\x18\x03 \x01(\x04\x12\x39\n\nTabletType\x18\x04 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\r\n\x05Owner\x18\x05 \x01(\x06\x12\x10\n\x08OwnerIdx\x18\x06 \x01(\x04\"\x95\x01\n\x13TEvAdoptTabletReply\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x0e\n\x06Origin\x18\x02 \x01(\x06\x12\r\n\x05Owner\x18\x03 \x01(\x06\x12\x10\n\x08OwnerIdx\x18\x04 \x01(\x04\x12*\n\x06Status\x18\x05 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0f\n\x07\x45xplain\x18\x06 \x01(\t\"\x98\x01\n\x19TEvReconfigureTabletReply\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x10\n\x08TabletID\x18\x02 \x01(\x06\x12\x10\n\x08\x41utoboot\x18\x03 \x01(\x08\x12+\n\x08\x43hannels\x18\x04 \x03(\x0b\x32\x19.NKikimrHive.TChannelInfo\"i\n\x0fTEvDeleteTablet\x12\x14\n\x0cShardOwnerId\x18\x01 \x01(\x06\x12\x15\n\rShardLocalIdx\x18\x02 \x03(\x04\x12\x17\n\x0fTxId_Deprecated\x18\x03 \x01(\x04\x12\x10\n\x08TabletID\x18\x04 \x03(\x06\"\xce\x01\n\x14TEvDeleteTabletReply\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0e\n\x06Origin\x18\x02 \x01(\x06\x12\x17\n\x0fTxId_Deprecated\x18\x03 \x01(\x04\x12\x14\n\x0cShardOwnerId\x18\x04 \x01(\x04\x12\x15\n\rShardLocalIdx\x18\x05 \x03(\x04\x12\x34\n\x0e\x46orwardRequest\x18\x06 \x01(\x0b\x32\x1c.NKikimrHive.TForwardRequest\"4\n\x15TEvDeleteOwnerTablets\x12\r\n\x05Owner\x18\x01 \x01(\x06\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\"u\n\x1aTEvDeleteOwnerTabletsReply\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\r\n\x05Owner\x18\x02 \x01(\x06\x12\x0c\n\x04TxId\x18\x03 \x01(\x04\x12\x0e\n\x06Origin\x18\x04 \x01(\x06\"Q\n\x14TEvLookupChannelInfo\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x10\n\x08\x43hannels\x18\x02 \x03(\r\x12\x15\n\rForGeneration\x18\x03 \x03(\r\"~\n\x0eTEvChannelInfo\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x10\n\x08TabletID\x18\x02 \x01(\x06\x12.\n\x0b\x43hannelInfo\x18\x03 \x03(\x0b\x32\x19.NKikimrHive.TChannelInfo\"j\n\x0eTTabletMetrics\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x32\n\rResourceUsage\x18\x04 \x01(\x0b\x32\x1b.NKikimrTabletBase.TMetrics\x12\x12\n\nFollowerID\x18\x03 \x01(\r\"\x97\x01\n\x10TEvTabletMetrics\x12\x32\n\rTabletMetrics\x18\x01 \x03(\x0b\x32\x1b.NKikimrHive.TTabletMetrics\x12\x37\n\x12TotalResourceUsage\x18\x02 \x01(\x0b\x32\x1b.NKikimrTabletBase.TMetrics\x12\x16\n\x0eTotalNodeUsage\x18\x03 \x01(\x01\"\xef\x01\n\x11TEvReassignTablet\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x10\n\x08\x43hannels\x18\x02 \x03(\r\x12\x16\n\x0e\x46orcedGroupIDs\x18\x03 \x03(\r\x12J\n\x0eReassignReason\x18\x04 \x01(\x0e\x32\x32.NKikimrHive.TEvReassignTablet.EHiveReassignReason\"R\n\x13\x45HiveReassignReason\x12\x1b\n\x17HIVE_REASSIGN_REASON_NO\x10\x00\x12\x1e\n\x1aHIVE_REASSIGN_REASON_SPACE\x10\x01\"\'\n\x0fTForwardRequest\x12\x14\n\x0cHiveTabletId\x18\x01 \x01(\x06\"\xc3\x01\n\x12TEvRequestHiveInfo\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x39\n\nTabletType\x18\x02 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\x17\n\x0fReturnFollowers\x18\x03 \x01(\x08\x12\x12\n\nFollowerID\x18\x04 \x01(\r\x12\x15\n\rReturnMetrics\x18\x05 \x01(\x08\x12\x1c\n\x14ReturnChannelHistory\x18\x06 \x01(\x08\"\xad\x01\n\x13TEvResponseHiveInfo\x12)\n\x07Tablets\x18\x01 \x03(\x0b\x32\x18.NKikimrHive.TTabletInfo\x12\x34\n\x0e\x46orwardRequest\x18\x02 \x01(\x0b\x32\x1c.NKikimrHive.TForwardRequest\x12\x1a\n\x12StartTimeTimestamp\x18\x03 \x01(\x04\x12\x19\n\x11ResponseTimestamp\x18\x04 \x01(\x04\"K\n\x19TEvRequestHiveDomainStats\x12\x17\n\x0fReturnFollowers\x18\x03 \x01(\x08\x12\x15\n\rReturnMetrics\x18\x05 \x01(\x08\"e\n\x1aTHiveDomainStatsStateCount\x12\x38\n\rVolatileState\x18\x01 \x01(\x0e\x32!.NKikimrHive.ETabletVolatileState\x12\r\n\x05\x43ount\x18\x02 \x01(\r\"\xc3\x01\n\x10THiveDomainStats\x12\x0f\n\x07ShardId\x18\x01 \x01(\x06\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12;\n\nStateStats\x18\x03 \x03(\x0b\x32\'.NKikimrHive.THiveDomainStatsStateCount\x12,\n\x07Metrics\x18\x04 \x01(\x0b\x32\x1b.NKikimrTabletBase.TMetrics\x12\x0f\n\x07NodeIds\x18\x05 \x03(\r\x12\x12\n\nAliveNodes\x18\x06 \x01(\r\"P\n\x1aTEvResponseHiveDomainStats\x12\x32\n\x0b\x44omainStats\x18\x01 \x03(\x0b\x32\x1d.NKikimrHive.THiveDomainStats\"0\n\x17TEvRequestHiveNodeStats\x12\x15\n\rReturnMetrics\x18\x05 \x01(\x08\"\xf5\x01\n\x0eTHiveNodeStats\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12;\n\nStateStats\x18\x03 \x03(\x0b\x32\'.NKikimrHive.THiveDomainStatsStateCount\x12,\n\x07Metrics\x18\x04 \x01(\x0b\x32\x1b.NKikimrTabletBase.TMetrics\x12\x19\n\x11RestartsPerPeriod\x18\x06 \x01(\r\x12\x1a\n\x12LastAliveTimestamp\x18\x07 \x01(\x04\x12\x31\n\nNodeDomain\x18\x08 \x01(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\"J\n\x18TEvResponseHiveNodeStats\x12.\n\tNodeStats\x18\x01 \x03(\x0b\x32\x1b.NKikimrHive.THiveNodeStats\"\x1c\n\x1aTEvRequestHiveStorageStats\"\xfb\x01\n\x16THiveStorageGroupStats\x12\x0f\n\x07GroupID\x18\x01 \x01(\r\x12\x15\n\rAcquiredUnits\x18\x02 \x01(\x04\x12\x14\n\x0c\x41\x63quiredIOPS\x18\x03 \x01(\x02\x12\x1a\n\x12\x41\x63quiredThroughput\x18\x04 \x01(\x04\x12\x14\n\x0c\x41\x63quiredSize\x18\x05 \x01(\x04\x12\x13\n\x0bMaximumIOPS\x18\x07 \x01(\x02\x12\x19\n\x11MaximumThroughput\x18\x08 \x01(\x04\x12\x13\n\x0bMaximumSize\x18\t \x01(\x04\x12\x15\n\rAllocatedSize\x18\n \x01(\x04\x12\x15\n\rAvailableSize\x18\x0b \x01(\x04\"Z\n\x15THiveStoragePoolStats\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x33\n\x06Groups\x18\x02 \x03(\x0b\x32#.NKikimrHive.THiveStorageGroupStats\"P\n\x1bTEvResponseHiveStorageStats\x12\x31\n\x05Pools\x18\x01 \x03(\x0b\x32\".NKikimrHive.THiveStoragePoolStats\"/\n\x0cTTabletOwner\x12\r\n\x05Owner\x18\x01 \x01(\x06\x12\x10\n\x08OwnerIdx\x18\x02 \x01(\x04\"e\n\x0cTEvDrainNode\x12\x0e\n\x06NodeID\x18\x01 \x01(\r\x12\x15\n\x07Persist\x18\x03 \x01(\x08:\x04true\x12\x17\n\x08KeepDown\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x15\n\rDrainInFlight\x18\x05 \x01(\r\"S\n\x12TEvDrainNodeResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x11\n\tMovements\x18\x02 \x01(\r\"\x1d\n\x0bTEvFillNode\x12\x0e\n\x06NodeID\x18\x01 \x01(\r\"?\n\x11TEvFillNodeResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\"+\n\x17TEvGetTabletStorageInfo\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\"\xa9\x01\n\x1dTEvGetTabletStorageInfoResult\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12*\n\x06Status\x18\x02 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x33\n\x04Info\x18\x03 \x01(\x0b\x32%.NKikimrTabletBase.TTabletStorageInfo\x12\x15\n\rStatusMessage\x18\x04 \x01(\t\"5\n!TEvGetTabletStorageInfoRegistered\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\"\x86\x01\n\x16TEvLockTabletExecution\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12*\n\nOwnerActor\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x11\n\tReconnect\x18\x03 \x01(\x08\x12\x1b\n\x13MaxReconnectTimeout\x18\x04 \x01(\x04\".\n\x1aTEvLockTabletExecutionLost\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\"s\n\x1cTEvLockTabletExecutionResult\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12*\n\x06Status\x18\x02 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x15\n\rStatusMessage\x18\x03 \x01(\t\"X\n\x18TEvUnlockTabletExecution\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12*\n\nOwnerActor\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\"u\n\x1eTEvUnlockTabletExecutionResult\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12*\n\x06Status\x18\x02 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x15\n\rStatusMessage\x18\x03 \x01(\t\"4\n\x19TEvInvalidateStoragePools\x12\x17\n\x0fStoragePoolName\x18\x01 \x03(\t\" \n\x1eTEvInvalidateStoragePoolsReply\"-\n\x1aTEvReassignOnDecommitGroup\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\"!\n\x1fTEvReassignOnDecommitGroupReply\"T\n\x1aTEvRequestTabletIdSequence\x12(\n\x05Owner\x18\x01 \x01(\x0b\x32\x19.NKikimrHive.TTabletOwner\x12\x0c\n\x04Size\x18\x02 \x01(\x04\"g\n\x1bTEvResponseTabletIdSequence\x12(\n\x05Owner\x18\x01 \x01(\x0b\x32\x19.NKikimrHive.TTabletOwner\x12\x0f\n\x07\x42\x65ginId\x18\x02 \x01(\x04\x12\r\n\x05\x45ndId\x18\x03 \x01(\x04\"\x9c\x01\n\x0fTEvSeizeTablets\x12\x12\n\nNewOwnerID\x18\x01 \x01(\x06\x12\x33\n\x0c\x46ilterDomain\x18\x02 \x01(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\x12\x1c\n\x11MaxTabletsToSeize\x18\x03 \x01(\r:\x01\x31\x12\"\n\x14WaitForTabletsToRise\x18\x04 \x01(\x08:\x04true\"^\n\x15TTabletChannelGenInfo\x12\x12\n\nGeneration\x18\x01 \x01(\x04\x12\r\n\x05Group\x18\x02 \x01(\x04\x12\x0f\n\x07Version\x18\x03 \x01(\x04\x12\x11\n\tTimestamp\x18\x04 \x01(\x04\"\xa7\x01\n\x12TTabletChannelInfo\x12\x13\n\x0bStoragePool\x18\x01 \x01(\t\x12\x31\n\x07\x42inding\x18\x02 \x01(\x0b\x32 .NKikimrStoragePool.TChannelBind\x12\x33\n\x07History\x18\x03 \x03(\x0b\x32\".NKikimrHive.TTabletChannelGenInfo\x12\x14\n\x0cNeedNewGroup\x18\x04 \x01(\x08\"\xa0\x07\n\x0bTTabletInfo\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x39\n\nTabletType\x18\x02 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\x38\n\rVolatileState\x18\x03 \x01(\x0e\x32!.NKikimrHive.ETabletVolatileState\x12\x0e\n\x06NodeID\x18\x04 \x01(\r\x12\x18\n\x10\x45xecutorCounters\x18\x05 \x03(\x04\x12\x1b\n\x13\x41pplicationCounters\x18\x06 \x03(\x04\x12.\n\x0bTabletOwner\x18\x07 \x01(\x0b\x32\x19.NKikimrHive.TTabletOwner\x12\x12\n\nFollowerID\x18\x08 \x01(\r\x12\r\n\x05State\x18\t \x01(\r\x12,\n\x07Metrics\x18\n \x01(\x0b\x32\x1b.NKikimrTabletBase.TMetrics\x12\x12\n\nGeneration\x18\x0b \x01(\r\x12\x34\n\x0eTabletBootMode\x18\x0c \x01(\x0e\x32\x1c.NKikimrHive.ETabletBootMode\x12\x33\n\x0cObjectDomain\x18\r \x01(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\x12\x10\n\x08ObjectId\x18\x0e \x01(\x04\x12\x35\n\x0e\x41llowedDomains\x18\x0f \x03(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\x12\x33\n\x0e\x46ollowerGroups\x18\x10 \x03(\x0b\x32\x1b.NKikimrHive.TFollowerGroup\x12\x37\n\x0eTabletChannels\x18\x11 \x03(\x0b\x32\x1f.NKikimrHive.TTabletChannelInfo\x12-\n\rLockedToActor\x18\x12 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x1e\n\x16LockedReconnectTimeout\x18\x13 \x01(\x04\x12\x1c\n\x14TabletStorageVersion\x18\x14 \x01(\x04\x12\x32\n\rResourceUsage\x18\x15 \x01(\x0b\x32\x1b.NKikimrTabletBase.TMetrics\x12\x19\n\x11RestartsPerPeriod\x18\x16 \x01(\r\x12\x1a\n\x12LastAliveTimestamp\x18\x17 \x01(\x04\x12\x34\n\x0e\x42\x61lancerPolicy\x18\x18 \x01(\x0e\x32\x1c.NKikimrHive.EBalancerPolicy\"A\n\x14TEvSeizeTabletsReply\x12)\n\x07Tablets\x18\x01 \x03(\x0b\x32\x18.NKikimrHive.TTabletInfo\":\n\x11TEvReleaseTablets\x12\x12\n\nNewOwnerID\x18\x01 \x01(\x06\x12\x11\n\tTabletIDs\x18\x02 \x03(\x06\"+\n\x16TEvReleaseTabletsReply\x12\x11\n\tTabletIDs\x18\x01 \x03(\x06\"A\n\x10TEvConfigureHive\x12-\n\x06\x44omain\x18\x01 \x01(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\"I\n\x10TEvInitMigration\x12\x35\n\x0fMigrationFilter\x18\x01 \x01(\x0b\x32\x1c.NKikimrHive.TEvSeizeTablets\"C\n\x15TEvInitMigrationReply\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\"\x13\n\x11TEvQueryMigration\"i\n\x16TEvQueryMigrationReply\x12\x34\n\x0eMigrationState\x18\x01 \x01(\x0e\x32\x1c.NKikimrHive.EMigrationState\x12\x19\n\x11MigrationProgress\x18\x02 \x01(\x05\"I\n\x11TTabletStatistics\x12\x18\n\x10RestartTimestamp\x18\x01 \x03(\x04\x12\x1a\n\x12LastAliveTimestamp\x18\x02 \x01(\x04\"G\n\x0fTNodeStatistics\x12\x18\n\x10RestartTimestamp\x18\x01 \x03(\x04\x12\x1a\n\x12LastAliveTimestamp\x18\x02 \x01(\x04\")\n\x16TEvRequestTabletOwners\x12\x0f\n\x07OwnerID\x18\x01 \x01(\x06\"A\n\x12TTabletOwnerRecord\x12\x0f\n\x07OwnerID\x18\x01 \x01(\x06\x12\r\n\x05\x42\x65gin\x18\x02 \x01(\x04\x12\x0b\n\x03\x45nd\x18\x03 \x01(\x04\"M\n\x14TEvTabletOwnersReply\x12\x35\n\x0cTabletOwners\x18\x01 \x03(\x0b\x32\x1f.NKikimrHive.TTabletOwnerRecord*N\n\x0f\x45TabletBootMode\x12\x1c\n\x18TABLET_BOOT_MODE_DEFAULT\x10\x00\x12\x1d\n\x19TABLET_BOOT_MODE_EXTERNAL\x10\x01*8\n\x0f\x45\x42\x61lancerPolicy\x12\x12\n\x0ePOLICY_BALANCE\x10\x00\x12\x11\n\rPOLICY_IGNORE\x10\x01*u\n\x0c\x45\x45rrorReason\x12\x18\n\x14\x45RROR_REASON_UNKNOWN\x10\x00\x12\'\n#ERROR_REASON_CHANNELS_CANNOT_SHRINK\x10\x01\x12\"\n\x1e\x45RROR_REASON_INVALID_ARGUMENTS\x10\x02*\xea\x01\n\x14\x45TabletVolatileState\x12!\n\x1dTABLET_VOLATILE_STATE_UNKNOWN\x10\x00\x12!\n\x1dTABLET_VOLATILE_STATE_STOPPED\x10\x01\x12!\n\x1dTABLET_VOLATILE_STATE_BOOTING\x10\x02\x12\"\n\x1eTABLET_VOLATILE_STATE_STARTING\x10\x03\x12!\n\x1dTABLET_VOLATILE_STATE_RUNNING\x10\x04\x12\"\n\x1e_TABLET_VOLATILE_STATE_BLOCKED\x10\x05*k\n\x0f\x45MigrationState\x12\x15\n\x11MIGRATION_UNKNOWN\x10\x00\x12\x13\n\x0fMIGRATION_READY\x10\x01\x12\x14\n\x10MIGRATION_ACTIVE\x10\x02\x12\x16\n\x12MIGRATION_COMPLETE\x10\x03\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.hive_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TDATACENTERSGROUP.fields_by_name['DataCenterNum']._options = None
  _TDATACENTERSGROUP.fields_by_name['DataCenterNum']._serialized_options = b'\030\001'
  _TEVCREATETABLET.fields_by_name['AllowedDataCenterNumIDs']._options = None
  _TEVCREATETABLET.fields_by_name['AllowedDataCenterNumIDs']._serialized_options = b'\030\001'
  _TEVCREATETABLET.fields_by_name['ChannelsProfile']._options = None
  _TEVCREATETABLET.fields_by_name['ChannelsProfile']._serialized_options = b'\030\001'
  _TEVCREATETABLET.fields_by_name['Flags']._options = None
  _TEVCREATETABLET.fields_by_name['Flags']._serialized_options = b'\030\001'
  _TEVCREATETABLET.fields_by_name['BootTimeoutMilliSeconds']._options = None
  _TEVCREATETABLET.fields_by_name['BootTimeoutMilliSeconds']._serialized_options = b'\030\001'
  _TEVCREATETABLET.fields_by_name['BootAttemptLimit']._options = None
  _TEVCREATETABLET.fields_by_name['BootAttemptLimit']._serialized_options = b'\030\001'
  _TEVCREATETABLET.fields_by_name['Weight']._options = None
  _TEVCREATETABLET.fields_by_name['Weight']._serialized_options = b'\030\001'
  _ETABLETBOOTMODE._serialized_start=9724
  _ETABLETBOOTMODE._serialized_end=9802
  _EBALANCERPOLICY._serialized_start=9804
  _EBALANCERPOLICY._serialized_end=9860
  _EERRORREASON._serialized_start=9862
  _EERRORREASON._serialized_end=9979
  _ETABLETVOLATILESTATE._serialized_start=9982
  _ETABLETVOLATILESTATE._serialized_end=10216
  _EMIGRATIONSTATE._serialized_start=10218
  _EMIGRATIONSTATE._serialized_end=10325
  _TCHANNELINFO._serialized_start=263
  _TCHANNELINFO._serialized_end=436
  _TCHANNELINFO_THISTORYSLOT._serialized_start=362
  _TCHANNELINFO_THISTORYSLOT._serialized_end=436
  _TEVBOOTTABLET._serialized_start=438
  _TEVBOOTTABLET._serialized_end=471
  _TEVBOOTTABLETREPLY._serialized_start=473
  _TEVBOOTTABLETREPLY._serialized_end=556
  _TTABLETCATEGORY._serialized_start=558
  _TTABLETCATEGORY._serialized_end=658
  _TDATACENTERSGROUP._serialized_start=660
  _TDATACENTERSGROUP._serialized_end=726
  _TDATACENTERSPREFERENCE._serialized_start=728
  _TDATACENTERSPREFERENCE._serialized_end=811
  _TEVCREATETABLET._serialized_start=814
  _TEVCREATETABLET._serialized_end=1810
  _TEVLOOKUPTABLET._serialized_start=1812
  _TEVLOOKUPTABLET._serialized_end=1862
  _TEVCREATETABLETREPLY._serialized_start=1865
  _TEVCREATETABLETREPLY._serialized_end=2100
  _TEVTABLETCREATIONRESULT._serialized_start=2102
  _TEVTABLETCREATIONRESULT._serialized_end=2189
  _TEVSTOPTABLET._serialized_start=2191
  _TEVSTOPTABLET._serialized_end=2271
  _TEVSTOPTABLETRESULT._serialized_start=2273
  _TEVSTOPTABLETRESULT._serialized_end=2356
  _TEVRESUMETABLETRESULT._serialized_start=2358
  _TEVRESUMETABLETRESULT._serialized_end=2443
  _TCHANNELREQUEST._serialized_start=2445
  _TCHANNELREQUEST._serialized_end=2506
  _TEVRECONFIGURETABLET._serialized_start=2509
  _TEVRECONFIGURETABLET._serialized_end=2653
  _TEVADOPTTABLET._serialized_start=2656
  _TEVADOPTTABLET._serialized_end=2823
  _TEVADOPTTABLETREPLY._serialized_start=2826
  _TEVADOPTTABLETREPLY._serialized_end=2975
  _TEVRECONFIGURETABLETREPLY._serialized_start=2978
  _TEVRECONFIGURETABLETREPLY._serialized_end=3130
  _TEVDELETETABLET._serialized_start=3132
  _TEVDELETETABLET._serialized_end=3237
  _TEVDELETETABLETREPLY._serialized_start=3240
  _TEVDELETETABLETREPLY._serialized_end=3446
  _TEVDELETEOWNERTABLETS._serialized_start=3448
  _TEVDELETEOWNERTABLETS._serialized_end=3500
  _TEVDELETEOWNERTABLETSREPLY._serialized_start=3502
  _TEVDELETEOWNERTABLETSREPLY._serialized_end=3619
  _TEVLOOKUPCHANNELINFO._serialized_start=3621
  _TEVLOOKUPCHANNELINFO._serialized_end=3702
  _TEVCHANNELINFO._serialized_start=3704
  _TEVCHANNELINFO._serialized_end=3830
  _TTABLETMETRICS._serialized_start=3832
  _TTABLETMETRICS._serialized_end=3938
  _TEVTABLETMETRICS._serialized_start=3941
  _TEVTABLETMETRICS._serialized_end=4092
  _TEVREASSIGNTABLET._serialized_start=4095
  _TEVREASSIGNTABLET._serialized_end=4334
  _TEVREASSIGNTABLET_EHIVEREASSIGNREASON._serialized_start=4252
  _TEVREASSIGNTABLET_EHIVEREASSIGNREASON._serialized_end=4334
  _TFORWARDREQUEST._serialized_start=4336
  _TFORWARDREQUEST._serialized_end=4375
  _TEVREQUESTHIVEINFO._serialized_start=4378
  _TEVREQUESTHIVEINFO._serialized_end=4573
  _TEVRESPONSEHIVEINFO._serialized_start=4576
  _TEVRESPONSEHIVEINFO._serialized_end=4749
  _TEVREQUESTHIVEDOMAINSTATS._serialized_start=4751
  _TEVREQUESTHIVEDOMAINSTATS._serialized_end=4826
  _THIVEDOMAINSTATSSTATECOUNT._serialized_start=4828
  _THIVEDOMAINSTATSSTATECOUNT._serialized_end=4929
  _THIVEDOMAINSTATS._serialized_start=4932
  _THIVEDOMAINSTATS._serialized_end=5127
  _TEVRESPONSEHIVEDOMAINSTATS._serialized_start=5129
  _TEVRESPONSEHIVEDOMAINSTATS._serialized_end=5209
  _TEVREQUESTHIVENODESTATS._serialized_start=5211
  _TEVREQUESTHIVENODESTATS._serialized_end=5259
  _THIVENODESTATS._serialized_start=5262
  _THIVENODESTATS._serialized_end=5507
  _TEVRESPONSEHIVENODESTATS._serialized_start=5509
  _TEVRESPONSEHIVENODESTATS._serialized_end=5583
  _TEVREQUESTHIVESTORAGESTATS._serialized_start=5585
  _TEVREQUESTHIVESTORAGESTATS._serialized_end=5613
  _THIVESTORAGEGROUPSTATS._serialized_start=5616
  _THIVESTORAGEGROUPSTATS._serialized_end=5867
  _THIVESTORAGEPOOLSTATS._serialized_start=5869
  _THIVESTORAGEPOOLSTATS._serialized_end=5959
  _TEVRESPONSEHIVESTORAGESTATS._serialized_start=5961
  _TEVRESPONSEHIVESTORAGESTATS._serialized_end=6041
  _TTABLETOWNER._serialized_start=6043
  _TTABLETOWNER._serialized_end=6090
  _TEVDRAINNODE._serialized_start=6092
  _TEVDRAINNODE._serialized_end=6193
  _TEVDRAINNODERESULT._serialized_start=6195
  _TEVDRAINNODERESULT._serialized_end=6278
  _TEVFILLNODE._serialized_start=6280
  _TEVFILLNODE._serialized_end=6309
  _TEVFILLNODERESULT._serialized_start=6311
  _TEVFILLNODERESULT._serialized_end=6374
  _TEVGETTABLETSTORAGEINFO._serialized_start=6376
  _TEVGETTABLETSTORAGEINFO._serialized_end=6419
  _TEVGETTABLETSTORAGEINFORESULT._serialized_start=6422
  _TEVGETTABLETSTORAGEINFORESULT._serialized_end=6591
  _TEVGETTABLETSTORAGEINFOREGISTERED._serialized_start=6593
  _TEVGETTABLETSTORAGEINFOREGISTERED._serialized_end=6646
  _TEVLOCKTABLETEXECUTION._serialized_start=6649
  _TEVLOCKTABLETEXECUTION._serialized_end=6783
  _TEVLOCKTABLETEXECUTIONLOST._serialized_start=6785
  _TEVLOCKTABLETEXECUTIONLOST._serialized_end=6831
  _TEVLOCKTABLETEXECUTIONRESULT._serialized_start=6833
  _TEVLOCKTABLETEXECUTIONRESULT._serialized_end=6948
  _TEVUNLOCKTABLETEXECUTION._serialized_start=6950
  _TEVUNLOCKTABLETEXECUTION._serialized_end=7038
  _TEVUNLOCKTABLETEXECUTIONRESULT._serialized_start=7040
  _TEVUNLOCKTABLETEXECUTIONRESULT._serialized_end=7157
  _TEVINVALIDATESTORAGEPOOLS._serialized_start=7159
  _TEVINVALIDATESTORAGEPOOLS._serialized_end=7211
  _TEVINVALIDATESTORAGEPOOLSREPLY._serialized_start=7213
  _TEVINVALIDATESTORAGEPOOLSREPLY._serialized_end=7245
  _TEVREASSIGNONDECOMMITGROUP._serialized_start=7247
  _TEVREASSIGNONDECOMMITGROUP._serialized_end=7292
  _TEVREASSIGNONDECOMMITGROUPREPLY._serialized_start=7294
  _TEVREASSIGNONDECOMMITGROUPREPLY._serialized_end=7327
  _TEVREQUESTTABLETIDSEQUENCE._serialized_start=7329
  _TEVREQUESTTABLETIDSEQUENCE._serialized_end=7413
  _TEVRESPONSETABLETIDSEQUENCE._serialized_start=7415
  _TEVRESPONSETABLETIDSEQUENCE._serialized_end=7518
  _TEVSEIZETABLETS._serialized_start=7521
  _TEVSEIZETABLETS._serialized_end=7677
  _TTABLETCHANNELGENINFO._serialized_start=7679
  _TTABLETCHANNELGENINFO._serialized_end=7773
  _TTABLETCHANNELINFO._serialized_start=7776
  _TTABLETCHANNELINFO._serialized_end=7943
  _TTABLETINFO._serialized_start=7946
  _TTABLETINFO._serialized_end=8874
  _TEVSEIZETABLETSREPLY._serialized_start=8876
  _TEVSEIZETABLETSREPLY._serialized_end=8941
  _TEVRELEASETABLETS._serialized_start=8943
  _TEVRELEASETABLETS._serialized_end=9001
  _TEVRELEASETABLETSREPLY._serialized_start=9003
  _TEVRELEASETABLETSREPLY._serialized_end=9046
  _TEVCONFIGUREHIVE._serialized_start=9048
  _TEVCONFIGUREHIVE._serialized_end=9113
  _TEVINITMIGRATION._serialized_start=9115
  _TEVINITMIGRATION._serialized_end=9188
  _TEVINITMIGRATIONREPLY._serialized_start=9190
  _TEVINITMIGRATIONREPLY._serialized_end=9257
  _TEVQUERYMIGRATION._serialized_start=9259
  _TEVQUERYMIGRATION._serialized_end=9278
  _TEVQUERYMIGRATIONREPLY._serialized_start=9280
  _TEVQUERYMIGRATIONREPLY._serialized_end=9385
  _TTABLETSTATISTICS._serialized_start=9387
  _TTABLETSTATISTICS._serialized_end=9460
  _TNODESTATISTICS._serialized_start=9462
  _TNODESTATISTICS._serialized_end=9533
  _TEVREQUESTTABLETOWNERS._serialized_start=9535
  _TEVREQUESTTABLETOWNERS._serialized_end=9576
  _TTABLETOWNERRECORD._serialized_start=9578
  _TTABLETOWNERRECORD._serialized_end=9643
  _TEVTABLETOWNERSREPLY._serialized_start=9645
  _TEVTABLETOWNERSREPLY._serialized_end=9722
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/dq/proto/dq_state_load_plan.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1ydb/library/yql/dq/proto/dq_state_load_plan.proto\x12\x1eNYql.NDqProto.NDqStateLoadPlan\"\x81\x02\n\tTTaskPlan\x12=\n\tStateType\x18\x01 \x01(\x0e\x32*.NYql.NDqProto.NDqStateLoadPlan.EStateType\x12=\n\x07Program\x18\x02 \x01(\x0b\x32,.NYql.NDqProto.NDqStateLoadPlan.TProgramPlan\x12<\n\x07Sources\x18\x03 \x03(\x0b\x32+.NYql.NDqProto.NDqStateLoadPlan.TSourcePlan\x12\x38\n\x05Sinks\x18\x04 \x03(\x0b\x32).NYql.NDqProto.NDqStateLoadPlan.TSinkPlan\"M\n\x0cTProgramPlan\x12=\n\tStateType\x18\x01 \x01(\x0e\x32*.NYql.NDqProto.NDqStateLoadPlan.EStateType\"\xf7\x01\n\x0bTSourcePlan\x12=\n\tStateType\x18\x01 \x01(\x0e\x32*.NYql.NDqProto.NDqStateLoadPlan.EStateType\x12\x12\n\nInputIndex\x18\x02 \x01(\x04\x12[\n\x13\x46oreignTasksSources\x18\x03 \x03(\x0b\x32>.NYql.NDqProto.NDqStateLoadPlan.TSourcePlan.TForeignTaskSource\x1a\x38\n\x12TForeignTaskSource\x12\x0e\n\x06TaskId\x18\x01 \x01(\x04\x12\x12\n\nInputIndex\x18\x02 \x01(\x04\"_\n\tTSinkPlan\x12=\n\tStateType\x18\x01 \x01(\x0e\x32*.NYql.NDqProto.NDqStateLoadPlan.EStateType\x12\x13\n\x0bOutputIndex\x18\x02 \x01(\x04*j\n\nEStateType\x12\x1a\n\x16STATE_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10STATE_TYPE_EMPTY\x10\x01\x12\x12\n\x0eSTATE_TYPE_OWN\x10\x02\x12\x16\n\x12STATE_TYPE_FOREIGN\x10\x03\x42\x03\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.dq.proto.dq_state_load_plan_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _ESTATETYPE._serialized_start=771
  _ESTATETYPE._serialized_end=877
  _TTASKPLAN._serialized_start=86
  _TTASKPLAN._serialized_end=343
  _TPROGRAMPLAN._serialized_start=345
  _TPROGRAMPLAN._serialized_end=422
  _TSOURCEPLAN._serialized_start=425
  _TSOURCEPLAN._serialized_end=672
  _TSOURCEPLAN_TFOREIGNTASKSOURCE._serialized_start=616
  _TSOURCEPLAN_TFOREIGNTASKSOURCE._serialized_end=672
  _TSINKPLAN._serialized_start=674
  _TSINKPLAN._serialized_end=769
# @@protoc_insertion_point(module_scope)



import ydb.core.protos.blobstorage_config_pb2 as kikimr_bsconfig
import ydb.apps.dstool.lib.common as common
import ydb.apps.dstool.lib.table as table
import sys
from collections import defaultdict

description = 'List groups'


def add_options(p):
    p.add_argument('--show-vdisk-status', action='store_true', help='Show columns with VDisk status')
    p.add_argument('--show-vdisk-usage', action='store_true', help='Show columns with VDisk usage')
    table.TableOutput([], col_units=[]).add_options(p)


def do(args):
    base_config_and_storage_pools = common.fetch_base_config_and_storage_pools()

    base_config = base_config_and_storage_pools['BaseConfig']
    group_map = common.build_group_map(base_config)
    vslot_map = common.build_vslot_map(base_config)

    storage_pools = base_config_and_storage_pools['StoragePools']
    sp_name = common.build_storage_pool_names_map(storage_pools)

    all_columns = [
        'GroupId',
        'BoxId:PoolId',
        'PoolName',
        'BoxId',
        'PoolId',
        'Generation',
        'ErasureSpecies',
        'ExpectedStatus',
        'OperatingStatus',
        'SeenOperational',
        'VDisks_TOTAL',
        'VDisks_READY',
        'VDisks_ERROR',
        'VDisks_REPLICATING',
        'VDisks_INIT_PENDING',
        'Usage',
        'UsedSize',
        'AvailableSize',
        'TotalSize',
    ]
    visible_columns = [
        'GroupId',
        'BoxId:PoolId',
        'PoolName',
        'Generation',
        'ErasureSpecies',
        'OperatingStatus',
        'VDisks_TOTAL',
    ]
    col_units = {
        'Usage': '%',
        'UsedSize': 'bytes',
        'AvailableSize': 'bytes',
        'TotalSize': 'bytes',
    }

    if args.show_vdisk_status or args.all_columns:
        visible_columns.extend(['VDisks_READY', 'VDisks_ERROR', 'VDisks_REPLICATING', 'VDisks_INIT_PENDING'])

    if args.show_vdisk_usage or args.all_columns:
        visible_columns.extend(['Usage', 'UsedSize', 'AvailableSize', 'TotalSize'])

    table_output = table.TableOutput(all_columns, col_units=col_units, default_visible_columns=visible_columns)

    group_stat_map = defaultdict(lambda: defaultdict(int))
    for vslot_id, vslot in vslot_map.items():
        group_id = vslot.GroupId
        if not common.is_dynamic_group(group_id):
            common.print_if_verbose(args, 'Skipping non dynamic group %d of vslot %s' % (vslot.GroupId, vslot), file=sys.stderr)
            continue

        if group_id not in group_map:
            common.print_if_not_quiet(args, 'Unknown group id %d of vslot %s' % (vslot.GroupId, vslot), file=sys.stderr)
            continue

        group = group_map[group_id]
        group_stat = group_stat_map[group_id]

        group_stat['BoxId:PoolId'] = '[%d:%d]' % (group.BoxId, group.StoragePoolId)
        group_stat['PoolName'] = sp_name[(group.BoxId, group.StoragePoolId)]
        group_stat['GroupId'] = group.GroupId
        group_stat['Generation'] = group.GroupGeneration
        group_stat['ErasureSpecies'] = group.ErasureSpecies
        group_stat['ExpectedStatus'] = kikimr_bsconfig.TGroupStatus.E.Name(group.ExpectedStatus)
        group_stat['OperatingStatus'] = kikimr_bsconfig.TGroupStatus.E.Name(group.OperatingStatus)
        group_stat['SeenOperational'] = group.SeenOperational
        group_stat['UsedSize'] += vslot.VDiskMetrics.AllocatedSize
        group_stat['TotalSize'] += vslot.VDiskMetrics.AllocatedSize
        group_stat['AvailableSize'] += vslot.VDiskMetrics.AvailableSize
        group_stat['TotalSize'] += vslot.VDiskMetrics.AvailableSize

        for key in ['VDisks_TOTAL', 'VDisks_' + vslot.Status]:
            group_stat[key] += 1

    rows = []
    for group_stat in group_stat_map.values():
        # set missing columns to 0
        for column in visible_columns:
            if column not in group_stat:
                group_stat[column] = 0

        # calculate usage at the end
        group_stat['Usage'] = group_stat['UsedSize'] / group_stat['TotalSize'] if group_stat['TotalSize'] != 0 else 0.0

        rows.append(group_stat)

    table_output.dump(rows, args)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/pqconfig.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos.draft import persqueue_error_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_draft_dot_persqueue__error__codes__pb2
from ydb.public.api.protos.draft import persqueue_common_pb2 as ydb_dot_public_dot_api_dot_protos_dot_draft_dot_persqueue__common__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from ydb.core.protos import msgbus_kv_pb2 as ydb_dot_core_dot_protos_dot_msgbus__kv__pb2
from ydb.core.protos import node_limits_pb2 as ydb_dot_core_dot_protos_dot_node__limits__pb2
from ydb.core.protos import netclassifier_pb2 as ydb_dot_core_dot_protos_dot_netclassifier__pb2
from ydb.core.protos import services_pb2 as ydb_dot_core_dot_protos_dot_services__pb2
from ydb.core.protos import type_info_pb2 as ydb_dot_core_dot_protos_dot_type__info__pb2
from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eydb/core/protos/pqconfig.proto\x12\tNKikimrPQ\x1a\x37ydb/public/api/protos/draft/persqueue_error_codes.proto\x1a\x32ydb/public/api/protos/draft/persqueue_common.proto\x1a\x1aydb/core/protos/base.proto\x1a\x1fydb/core/protos/msgbus_kv.proto\x1a!ydb/core/protos/node_limits.proto\x1a#ydb/core/protos/netclassifier.proto\x1a\x1eydb/core/protos/services.proto\x1a\x1fydb/core/protos/type_info.proto\x1a&library/cpp/actors/protos/actors.proto\"8\n\x0eTPartitionMeta\x12\x13\n\x0bStartOffset\x18\x01 \x01(\x04\x12\x11\n\tEndOffset\x18\x02 \x01(\x04\"2\n\x10TPartitionTxMeta\x12\x10\n\x08PlanStep\x18\x01 \x01(\x04\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\"\xd5\x1d\n\tTPQConfig\x12\x1f\n\x12\x41\x43LRetryTimeoutSec\x18\x01 \x01(\r:\x03\x33\x30\x30\x12,\n\x1f\x42\x61lancerMetadataRetryTimeoutSec\x18\x02 \x01(\r:\x03\x32\x34\x30\x12\x1c\n\x10MaxBlobsPerLevel\x18\x03 \x01(\r:\x02\x36\x34\x12\x1c\n\x0bMaxBlobSize\x18\x04 \x01(\r:\x07\x38\x33\x38\x38\x36\x30\x38\x12$\n\x18\x43lustersUpdateTimeoutSec\x18\x05 \x01(\r:\x02\x33\x30\x12\x15\n\x07\x45nabled\x18\x06 \x01(\x08:\x04true\x12#\n\x13MetaCacheTimeoutSec\x18\x07 \x01(\r:\x02\x33\x30\x42\x02\x18\x01\x12\x1e\n\x0eMaxReadCookies\x18\x08 \x01(\r:\x06\x31\x30\x30\x30\x30\x30\x12\x16\n\x08\x43heckACL\x18\t \x01(\x08:\x04true\x12$\n\x18SourceIdCleanupPeriodSec\x18\n \x01(\r:\x02\x36\x30\x12\'\n\x16SourceIdMaxLifetimeSec\x18\x0b \x01(\r:\x07\x31\x33\x38\x32\x34\x30\x30\x12(\n\x18SourceIdTotalShardsCount\x18\x0c \x01(\r:\x06\x31\x33\x31\x30\x37\x32\x12G\n\x06Tactic\x18\r \x01(\x0e\x32\'.NKikimrClient.TKeyValueRequest.ETactic:\x0eMAX_THROUGHPUT\x12-\n\x1fRequireCredentialsInNewProtocol\x18\x0e \x01(\x08:\x04true\x12\x1a\n\x10\x43lusterTablePath\x18\x0f \x01(\t:\x00\x12\x1a\n\x10VersionTablePath\x18\x10 \x01(\t:\x00\x12*\n\x1f\x43lustersUpdateTimeoutOnErrorSec\x18\x11 \x01(\r:\x01\x31\x12\"\n\x15WriteInitLatencyBigMs\x18\x13 \x01(\r:\x03\x39\x30\x30\x12!\n\x14ReadInitLatencyBigMs\x18\x14 \x01(\r:\x03\x39\x30\x30\x12\x1f\n\x12\x43ommitLatencyBigMs\x18\x15 \x01(\r:\x03\x39\x30\x30\x12\x1e\n\x11WriteLatencyBigMs\x18\x16 \x01(\r:\x03\x35\x35\x30\x12\x1d\n\x10ReadLatencyBigMs\x18\x17 \x01(\r:\x03\x35\x35\x30\x12&\n\x18ReadLatencyFromDiskBigMs\x18\x1c \x01(\r:\x04\x31\x30\x30\x30\x12:\n\rQuotingConfig\x18\x12 \x01(\x0b\x32#.NKikimrPQ.TPQConfig.TQuotingConfig\x12)\n\x1cRemoteClusterEnabledDelaySec\x18\x18 \x01(\r:\x03\x33\x30\x30\x12H\n;CloseClientSessionWithEnabledRemotePreferredClusterDelaySec\x18\x19 \x01(\r:\x03\x33\x30\x30\x12(\n\x1aRoundRobinPartitionMapping\x18\x1a \x01(\x08:\x04true\x12\x0e\n\x04Root\x18\x1b \x01(\t:\x00\x12\x18\n\x10TestDatabaseRoot\x18/ \x01(\t\x12\x38\n\x0cMirrorConfig\x18\x1d \x01(\x0b\x32\".NKikimrPQ.TPQConfig.TMirrorConfig\x12\x1c\n\x11MinWriteLatencyMs\x18\x1e \x01(\x04:\x01\x30\x12\x33\n\x0f\x43hannelProfiles\x18\x1f \x03(\x0b\x32\x1a.NKikimrPQ.TChannelProfile\x12(\n\x1aTopicsAreFirstClassCitizen\x18  \x01(\x08:\x04true\x12.\n\x1fUseSrcIdMetaMappingInFirstClass\x18\x34 \x01(\x08:\x05\x66\x61lse\x12\x31\n\x11SourceIdTablePath\x18! \x01(\t:\x16/Root/PQ/SourceIdMeta2\x12%\n\x1dValidWriteSpeedLimitsKbPerSec\x18\" \x03(\r\x12G\n\x14ValidRetentionLimits\x18\x30 \x03(\x0b\x32).NKikimrPQ.TPQConfig.TValidRetentionLimit\x12J\n\x15\x42illingMeteringConfig\x18# \x01(\x0b\x32+.NKikimrPQ.TPQConfig.TBillingMeteringConfig\x12V\n\x13PersQueueNodeConfig\x18$ \x01(\x0b\x32\x39.NKikimrNodeLimits.TNodeLimitsConfig.TPersQueueNodeConfig\x12%\n\x17\x45nableProtoSourceIdInfo\x18% \x01(\x08:\x04true\x12\x10\n\x08\x44\x61tabase\x18& \x01(\t\x12\x32\n#ForceClientServiceTypePasswordCheck\x18\x31 \x01(\x08:\x05\x66\x61lse\x12\x42\n\x11\x43lientServiceType\x18\' \x03(\x0b\x32\'.NKikimrPQ.TPQConfig.TClientServiceType\x12I\n\x18\x44\x65\x66\x61ultClientServiceType\x18( \x01(\x0b\x32\'.NKikimrPQ.TPQConfig.TClientServiceType\x12/\n DisallowDefaultClientServiceType\x18+ \x01(\x08:\x05\x66\x61lse\x12\x37\n$MetaCacheRefreshIntervalMilliSeconds\x18) \x01(\r:\x05\x31\x30\x30\x30\x30\x42\x02\x18\x01\x12,\n\x19MetaCacheSkipVersionCheck\x18* \x01(\x08:\x05\x66\x61lseB\x02\x18\x01\x12\x19\n\x11NonChargeableUser\x18, \x03(\t\x12\x1c\n\x12LbCommunalDatabase\x18- \x01(\t:\x00\x12\x42\n\x11PQDiscoveryConfig\x18. \x01(\x0b\x32\'.NKikimrPQ.TPQConfig.TPQDiscoveryConfig\x12!\n\x12MaxStorageNodePort\x18\x32 \x01(\r:\x05\x31\x39\x30\x30\x31\x12H\n\x14MoveTopicActorConfig\x18\x33 \x01(\x0b\x32*.NKikimrPQ.TPQConfig.TMoveTopicActorConfig\x1a\xa2\x03\n\x0eTQuotingConfig\x12\x1b\n\rEnableQuoting\x18\x01 \x01(\x08:\x04true\x12\x1e\n\x14QuotersDirectoryPath\x18\x02 \x01(\t:\x00\x12k\n\x1cTopicWriteQuotaEntityToLimit\x18\x03 \x01(\x0e\x32\x32.NKikimrPQ.TPQConfig.TQuotingConfig.ELimitedEntity:\x11USER_PAYLOAD_SIZE\x12 \n\x11\x45nableReadQuoting\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x1f\n\x0fReadCreditBytes\x18\x05 \x01(\x04:\x06\x31\x30\x30\x30\x30\x30\x12\x1e\n\x13QuotaWaitDurationMs\x18\x06 \x01(\x04:\x01\x30\x12\x32\n#PartitionReadQuotaIsTwiceWriteQuota\x18\x07 \x01(\x08:\x05\x66\x61lse\"O\n\x0e\x45LimitedEntity\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x15\n\x11WRITTEN_BLOB_SIZE\x10\x01\x12\x15\n\x11USER_PAYLOAD_SIZE\x10\x02\x1a\x64\n\x0eTPQLibSettings\x12\x17\n\x0cThreadsCount\x18\x01 \x01(\r:\x01\x31\x12!\n\x16\x43ompressionPoolThreads\x18\x02 \x01(\r:\x01\x31\x12\x16\n\x0bGRpcThreads\x18\x03 \x01(\r:\x01\x31\x1a\x62\n\rTMirrorConfig\x12\x15\n\x07\x45nabled\x18\x01 \x01(\x08:\x04true\x12:\n\rPQLibSettings\x18\x02 \x01(\x0b\x32#.NKikimrPQ.TPQConfig.TPQLibSettings\x1a\x84\x01\n\x14TValidRetentionLimit\x12\x18\n\x10MinPeriodSeconds\x18\x01 \x01(\r\x12\x18\n\x10MaxPeriodSeconds\x18\x02 \x01(\r\x12\x1b\n\x13MinStorageMegabytes\x18\x03 \x01(\x04\x12\x1b\n\x13MaxStorageMegabytes\x18\x04 \x01(\x04\x1a\xc7\x01\n\x13TReadMeteringConfig\x12\x42\n\x07Pricing\x18\x02 \x03(\x0b\x32\x31.NKikimrPQ.TPQConfig.TReadMeteringConfig.TPricing\x12I\n\x0eUnknownPricing\x18\x03 \x01(\x0b\x32\x31.NKikimrPQ.TPQConfig.TReadMeteringConfig.TPricing\x1a!\n\x08TPricing\x12\x15\n\x04Name\x18\x01 \x01(\t:\x07unknown\x1a\x86\x01\n\x16TBillingMeteringConfig\x12\x16\n\x07\x45nabled\x18\x01 \x01(\x08:\x05\x66\x61lse\x12\x1c\n\x10\x46lushIntervalSec\x18\x02 \x01(\x04:\x02\x33\x30\x12\x36\n\x04Read\x18\x03 \x01(\x0b\x32(.NKikimrPQ.TPQConfig.TReadMeteringConfig\x1a\x87\x01\n\x12TClientServiceType\x12\x1a\n\x04Name\x18\x01 \x01(\t:\x0c\x64\x61ta-streams\x12\x17\n\x0fReadPricingName\x18\x02 \x01(\t\x12$\n\x19MaxReadRulesCountPerTopic\x18\x03 \x01(\r:\x01\x30\x12\x16\n\x0ePasswordHashes\x18\x04 \x03(\t\x1a\xc8\x01\n\x12TPQDiscoveryConfig\x12/\n CacheRefreshIntervalMilliSeconds\x18\x01 \x01(\r:\x05\x31\x30\x30\x30\x30\x12$\n\x15\x43\x61\x63heSkipVersionCheck\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\x1c\n\x0eLBFrontEnabled\x18\x03 \x01(\x08:\x04true\x12\x1f\n\x11UseLbAccountAlias\x18\x04 \x01(\x08:\x04true\x12\x1c\n\x12LbUserDatabaseRoot\x18\x05 \x01(\t:\x00\x1a\x30\n\x15TMoveTopicActorConfig\x12\x17\n\x0f\x41llowedUserSIDs\x18\x01 \x03(\t\"\x85\x01\n\x0fTChannelProfile\x12\x10\n\x08PoolKind\x18\x01 \x01(\t\x12\x0c\n\x04Size\x18\x02 \x01(\x04\x12\x10\n\x08ReadIops\x18\x03 \x01(\x01\x12\x15\n\rReadBandwidth\x18\x04 \x01(\x01\x12\x11\n\tWriteIops\x18\x05 \x01(\x01\x12\x16\n\x0eWriteBandwidth\x18\x06 \x01(\x01\"\xf0\x03\n\x16TMirrorPartitionConfig\x12\x10\n\x08\x45ndpoint\x18\x01 \x01(\t\x12\x14\n\x0c\x45ndpointPort\x18\x06 \x01(\r\x12\r\n\x05Topic\x18\x02 \x01(\t\x12\x10\n\x08\x43onsumer\x18\x03 \x01(\t\x12\x1c\n\x14ReadFromTimestampsMs\x18\x05 \x01(\x04\x12\x43\n\x0b\x43redentials\x18\x07 \x01(\x0b\x32..NKikimrPQ.TMirrorPartitionConfig.TCredentials\x12\x10\n\x08\x44\x61tabase\x18\x08 \x01(\t\x12\"\n\x13UseSecureConnection\x18\t \x01(\x08:\x05\x66\x61lse\x12\x1c\n\rSyncWriteTime\x18\n \x01(\x08:\x05\x66\x61lse\x1a\xd5\x01\n\x0cTCredentials\x12\x14\n\nOauthToken\x18\x01 \x01(\tH\x00\x12\x13\n\tJwtParams\x18\x02 \x01(\tH\x00\x12L\n\x03Iam\x18\x03 \x01(\x0b\x32=.NKikimrPQ.TMirrorPartitionConfig.TCredentials.IamCredentialsH\x00\x1a=\n\x0eIamCredentials\x12\x10\n\x08\x45ndpoint\x18\x01 \x01(\t\x12\x19\n\x11ServiceAccountKey\x18\x02 \x01(\tB\r\n\x0b\x43redentials\"\xfc\x05\n\x10TPartitionConfig\x12%\n\x13MaxCountInPartition\x18\x01 \x01(\x05:\x08\x31\x30\x30\x30\x30\x30\x30\x30\x12)\n\x12MaxSizeInPartition\x18\x02 \x01(\x03:\r1099511627776\x12\x1f\n\x0fLifetimeSeconds\x18\x03 \x01(\x05:\x06\x36\x30\x34\x38\x30\x30\x12\x19\n\x11StorageLimitBytes\x18\x10 \x01(\x04\x12\x19\n\x11ImportantClientId\x18\x04 \x03(\t\x12\x1d\n\x0cLowWatermark\x18\x05 \x01(\r:\x07\x36\x32\x39\x31\x34\x35\x36\x12(\n\x17SourceIdLifetimeSeconds\x18\x06 \x01(\r:\x07\x31\x33\x38\x32\x34\x30\x30\x12\"\n\x11SourceIdMaxCounts\x18\x1f \x01(\r:\x07\x36\x30\x30\x30\x30\x30\x30\x12,\n\x1aWriteSpeedInBytesPerSecond\x18\x07 \x01(\x04:\x08\x35\x30\x30\x30\x30\x30\x30\x30\x12\x1b\n\tBurstSize\x18\x08 \x01(\x04:\x08\x35\x30\x30\x30\x30\x30\x30\x30\x12\x39\n\tReadQuota\x18\x0b \x03(\x0b\x32&.NKikimrPQ.TPartitionConfig.TReadQuota\x12&\n\x14MaxWriteInflightSize\x18\t \x01(\x04:\x08\x33\x30\x30\x30\x30\x30\x30\x30\x12)\n\x17\x42orderWriteInflightSize\x18\x0c \x01(\x04:\x08\x31\x30\x30\x30\x30\x30\x30\x30\x12\x17\n\x0bNumChannels\x18\n \x01(\r:\x02\x31\x30\x12\x1a\n\x0fTotalPartitions\x18\r \x01(\r:\x01\x31\x12;\n\x17\x45xplicitChannelProfiles\x18\x0e \x03(\x0b\x32\x1a.NKikimrPQ.TChannelProfile\x12\x35\n\nMirrorFrom\x18\x0f \x01(\x0b\x32!.NKikimrPQ.TMirrorPartitionConfig\x1aP\n\nTReadQuota\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\x12\x1d\n\x15SpeedInBytesPerSecond\x18\x02 \x01(\x04\x12\x11\n\tBurstSize\x18\x03 \x01(\x04\"8\n\x12TPartitionKeyRange\x12\x11\n\tFromBound\x18\x01 \x01(\x0c\x12\x0f\n\x07ToBound\x18\x02 \x01(\x0c\"L\n\rTMessageGroup\x12\n\n\x02Id\x18\x01 \x01(\x0c\x12/\n\x08KeyRange\x18\x02 \x01(\x0b\x32\x1d.NKikimrPQ.TPartitionKeyRange\"\x8a\n\n\x0fTPQTabletConfig\x12\x1c\n\tCacheSize\x18\x01 \x01(\x04:\t104857600\x12\x34\n\x0fPartitionConfig\x18\x02 \x01(\x0b\x32\x1b.NKikimrPQ.TPartitionConfig\x12\x14\n\x0cPartitionIds\x18\x03 \x03(\r\x12\x11\n\tTopicName\x18\x04 \x01(\t\x12\x0f\n\x07Version\x18\x05 \x01(\r\x12\x16\n\x07LocalDC\x18\x06 \x01(\x08:\x05\x66\x61lse\x12\x1f\n\x10RequireAuthWrite\x18\x07 \x01(\x08:\x05\x66\x61lse\x12\x1e\n\x0fRequireAuthRead\x18\x08 \x01(\x08:\x05\x66\x61lse\x12\x10\n\x08Producer\x18\t \x01(\t\x12\r\n\x05Ident\x18\n \x01(\t\x12\r\n\x05Topic\x18\x0b \x01(\t\x12\n\n\x02\x44\x43\x18\x0c \x01(\t\x12\x11\n\tReadRules\x18\r \x03(\t\x12\x1c\n\x14ReadFromTimestampsMs\x18\x0e \x03(\x04\x12\x1e\n\x16\x43onsumerFormatVersions\x18\x0f \x03(\x04\x12:\n\x0e\x43onsumerCodecs\x18\x10 \x03(\x0b\x32\".NKikimrPQ.TPQTabletConfig.TCodecs\x12\x1c\n\x14ReadRuleServiceTypes\x18\x11 \x03(\t\x12\x15\n\rFormatVersion\x18\x14 \x01(\x04\x12\x32\n\x06\x43odecs\x18\x15 \x01(\x0b\x32\".NKikimrPQ.TPQTabletConfig.TCodecs\x12\x18\n\x10ReadRuleVersions\x18\x16 \x03(\x04\x12\x1b\n\x13ReadRuleGenerations\x18  \x03(\x04\x12\x11\n\tTopicPath\x18\x17 \x01(\t\x12\r\n\x05\x41\x62\x63Id\x18\x18 \x01(\x04\x12\x0f\n\x07\x41\x62\x63Slug\x18\x19 \x01(\t\x12\x13\n\tYcCloudId\x18\x1a \x01(\t:\x00\x12\x14\n\nYcFolderId\x18\x1b \x01(\t:\x00\x12\x17\n\rYdbDatabaseId\x18\x1c \x01(\t:\x00\x12\x19\n\x0fYdbDatabasePath\x18\x1d \x01(\t:\x00\x12\x1b\n\x11\x46\x65\x64\x65rationAccount\x18! \x01(\t:\x00\x12J\n\x12PartitionKeySchema\x18\x1e \x03(\x0b\x32..NKikimrPQ.TPQTabletConfig.TKeyComponentSchema\x12\x39\n\nPartitions\x18\x1f \x03(\x0b\x32%.NKikimrPQ.TPQTabletConfig.TPartition\x12>\n\x0cMeteringMode\x18\" \x01(\x0e\x32(.NKikimrPQ.TPQTabletConfig.EMeteringMode\x1a&\n\x07TCodecs\x12\x0b\n\x03Ids\x18\x01 \x03(\x03\x12\x0e\n\x06\x43odecs\x18\x02 \x03(\t\x1a^\n\x13TKeyComponentSchema\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0e\n\x06TypeId\x18\x02 \x01(\r\x12)\n\x08TypeInfo\x18\x03 \x01(\x0b\x32\x17.NKikimrProto.TTypeInfo\x1aR\n\nTPartition\x12\x13\n\x0bPartitionId\x18\x01 \x01(\r\x12/\n\x08KeyRange\x18\x02 \x01(\x0b\x32\x1d.NKikimrPQ.TPartitionKeyRange\"U\n\rEMeteringMode\x12#\n\x1fMETERING_MODE_RESERVED_CAPACITY\x10\x00\x12\x1f\n\x1bMETERING_MODE_REQUEST_UNITS\x10\x01\"\xad\x02\n\x11TMessageGroupInfo\x12\r\n\x05SeqNo\x18\x01 \x01(\x04\x12\x0e\n\x06Offset\x18\x02 \x01(\x04\x12\x16\n\x0eWriteTimestamp\x18\x03 \x01(\x04\x12\x17\n\x0f\x43reateTimestamp\x18\x04 \x01(\x04\x12\x10\n\x08\x45xplicit\x18\x05 \x01(\x08\x12/\n\x08KeyRange\x18\x06 \x01(\x0b\x32\x1d.NKikimrPQ.TPartitionKeyRange\x12\x32\n\x05State\x18\x07 \x01(\x0e\x32#.NKikimrPQ.TMessageGroupInfo.EState\"Q\n\x06\x45State\x12\x11\n\rSTATE_UNKNOWN\x10\x00\x12\x14\n\x10STATE_REGISTERED\x10\x01\x12\x1e\n\x1aSTATE_PENDING_REGISTRATION\x10\x02\"K\n\x10TBootstrapConfig\x12\x37\n\x15\x45xplicitMessageGroups\x18\x01 \x03(\x0b\x32\x18.NKikimrPQ.TMessageGroup\"\x85\x01\n\rTUpdateConfig\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x30\n\x0cTabletConfig\x18\x02 \x01(\x0b\x32\x1a.NKikimrPQ.TPQTabletConfig\x12\x34\n\x0f\x42ootstrapConfig\x18\x03 \x01(\x0b\x32\x1b.NKikimrPQ.TBootstrapConfig\"\xf5\x03\n\x15TUpdateBalancerConfig\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x11\n\tTopicName\x18\x03 \x01(\t\x12\x0c\n\x04Path\x18\x04 \x01(\t\x12\x0f\n\x07Version\x18\x05 \x01(\r\x12\x17\n\x0fTotalGroupCount\x18\x0b \x01(\r\x12\x17\n\x0fNextPartitionId\x18\x0c \x01(\r\x12\x30\n\x0cTabletConfig\x18\x07 \x01(\x0b\x32\x1a.NKikimrPQ.TPQTabletConfig\x12\x1a\n\x12PartitionPerTablet\x18\x08 \x01(\r\x12\x15\n\rSchemeShardId\x18\t \x01(\x04\x12?\n\nPartitions\x18\x06 \x03(\x0b\x32+.NKikimrPQ.TUpdateBalancerConfig.TPartition\x12\x39\n\x07Tablets\x18\n \x03(\x0b\x32(.NKikimrPQ.TUpdateBalancerConfig.TTablet\x1a@\n\nTPartition\x12\x11\n\tPartition\x18\x01 \x01(\r\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\x12\r\n\x05Group\x18\x03 \x01(\r\x1a\x37\n\x07TTablet\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\r\n\x05Owner\x18\x02 \x01(\x04\x12\x0b\n\x03Idx\x18\x03 \x01(\x04\"\x0b\n\tTDescribe\"\xb8\x02\n\x11TDescribeResponse\x12\x11\n\tTopicName\x18\x01 \x01(\t\x12\x0f\n\x07Version\x18\x02 \x01(\r\x12*\n\x06\x43onfig\x18\x03 \x01(\x0b\x32\x1a.NKikimrPQ.TPQTabletConfig\x12\x1a\n\x12PartitionPerTablet\x18\x04 \x01(\r\x12\x15\n\rSchemeShardId\x18\x06 \x01(\x04\x12\x18\n\x10\x42\x61lancerTabletId\x18\x07 \x01(\x04\x12\x16\n\x0eSecurityObject\x18\x08 \x01(\x0c\x12;\n\nPartitions\x18\x05 \x03(\x0b\x32\'.NKikimrPQ.TDescribeResponse.TPartition\x1a\x31\n\nTPartition\x12\x11\n\tPartition\x18\x01 \x01(\r\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\"\x7f\n\tTCheckACL\x12(\n\tOperation\x18\x02 \x01(\x0e\x32\x15.NKikimrPQ.EOperation\x12+\n\x04\x41uth\x18\x04 \x01(\x0b\x32\x1d.NPersQueueCommon.Credentials\x12\x0c\n\x04User\x18\x05 \x01(\t\x12\r\n\x05Token\x18\x06 \x01(\x0c\"c\n\x11TCheckACLResponse\x12\"\n\x06\x41\x63\x63\x65ss\x18\x01 \x01(\x0e\x32\x12.NKikimrPQ.EAccess\x12\r\n\x05Topic\x18\x02 \x01(\t\x12\x0c\n\x04Path\x18\x03 \x01(\t\x12\r\n\x05\x45rror\x18\x04 \x01(\t\"\x19\n\x17TGetPartitionIdForWrite\"6\n\x1fTGetPartitionIdForWriteResponse\x12\x13\n\x0bPartitionId\x18\x01 \x01(\x04\"\x89\x01\n\x14TRegisterReadSession\x12\x0f\n\x07Session\x18\x01 \x01(\t\x12*\n\nPipeClient\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x10\n\x08\x43lientId\x18\x03 \x01(\t\x12\x12\n\nClientNode\x18\x04 \x01(\t\x12\x0e\n\x06Groups\x18\x05 \x03(\r\"(\n\x14TGetReadSessionsInfo\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\"\x14\n\x12TReadSessionStatus\"\xd4\x02\n\x1aTReadSessionStatusResponse\x12I\n\tPartition\x18\x08 \x03(\x0b\x32\x36.NKikimrPQ.TReadSessionStatusResponse.TPartitionStatus\x12\x0f\n\x07Session\x18\x04 \x01(\t\x12\x11\n\tTimestamp\x18\x05 \x01(\x04\x12\x12\n\nClientNode\x18\x06 \x01(\t\x12\x13\n\x0bProxyNodeId\x18\x07 \x01(\r\x1a\x9d\x01\n\x10TPartitionStatus\x12\x13\n\x0bNextCommits\x18\x01 \x03(\x04\x12\x12\n\nLastReadId\x18\x02 \x01(\x04\x12\x17\n\x0fReadIdCommitted\x18\x03 \x01(\x04\x12\x10\n\x08\x41ssignId\x18\x04 \x01(\x04\x12\r\n\x05Topic\x18\x05 \x01(\t\x12\x11\n\tPartition\x18\x07 \x01(\x04\x12\x13\n\x0bTimestampMs\x18\x08 \x01(\x04\"\xa1\x03\n\x19TReadSessionsInfoResponse\x12J\n\rPartitionInfo\x18\x01 \x03(\x0b\x32\x33.NKikimrPQ.TReadSessionsInfoResponse.TPartitionInfo\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\x12K\n\x0cReadSessions\x18\x03 \x03(\x0b\x32\x35.NKikimrPQ.TReadSessionsInfoResponse.TReadSessionInfo\x1a\x85\x01\n\x0eTPartitionInfo\x12\x11\n\tPartition\x18\x01 \x01(\r\x12\x12\n\nClientNode\x18\x02 \x01(\t\x12\x13\n\x0bProxyNodeId\x18\x03 \x01(\r\x12\x0f\n\x07Session\x18\x04 \x01(\t\x12\x11\n\tTimestamp\x18\x05 \x01(\x04\x12\x13\n\x0bTimestampMs\x18\x06 \x01(\x04\x1aQ\n\x10TReadSessionInfo\x12,\n\x0cSessionActor\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x0f\n\x07Session\x18\x02 \x01(\t\"\xc3\x01\n\x0eTLockPartition\x12\x11\n\tPartition\x18\x01 \x01(\r\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\x12\r\n\x05Topic\x18\x03 \x01(\t\x12\x12\n\nGeneration\x18\x04 \x01(\r\x12\x0c\n\x04Step\x18\x05 \x01(\r\x12\x0f\n\x07Session\x18\x06 \x01(\t\x12\x10\n\x08\x43lientId\x18\x07 \x01(\t\x12*\n\nPipeClient\x18\x08 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x0c\n\x04Path\x18\t \x01(\t\"\xb1\x01\n\x11TReleasePartition\x12\r\n\x05Topic\x18\x01 \x01(\t\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12\x0f\n\x07Session\x18\x03 \x01(\t\x12\x10\n\x08\x43lientId\x18\x04 \x01(\t\x12\r\n\x05\x43ount\x18\x05 \x01(\r\x12*\n\nPipeClient\x18\x06 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\r\n\x05Group\x18\x07 \x01(\r\x12\x0c\n\x04Path\x18\x08 \x01(\t\"\x85\x01\n\x12TPartitionReleased\x12\x11\n\tPartition\x18\x01 \x01(\r\x12\r\n\x05Topic\x18\x02 \x01(\t\x12\x0f\n\x07Session\x18\x03 \x01(\t\x12*\n\nPipeClient\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x10\n\x08\x43lientId\x18\x05 \x01(\t\"L\n\x0bTDropTablet\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12/\n\x0eRequestedState\x18\x02 \x01(\x0e\x32\x17.NKikimrPQ.ETabletState\"\x8d\x01\n\x11TDropTabletResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x10\n\x08TabletId\x18\x03 \x01(\x04\x12,\n\x0b\x41\x63tualState\x18\x04 \x01(\x0e\x32\x17.NKikimrPQ.ETabletState\"6\n\x0cTTabletState\x12&\n\x05State\x18\x01 \x01(\x0e\x32\x17.NKikimrPQ.ETabletState\"Y\n\x15TUpdateConfigResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\"\n\x06Status\x18\x03 \x01(\x0e\x32\x12.NKikimrPQ.EStatus\"\x1c\n\x08TOffsets\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\"\xbb\x03\n\x10TOffsetsResponse\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12;\n\nPartResult\x18\x02 \x03(\x0b\x32\'.NKikimrPQ.TOffsetsResponse.TPartResult\x1a\xd7\x02\n\x0bTPartResult\x12\x11\n\tPartition\x18\x01 \x01(\x05\x12\x13\n\x0bStartOffset\x18\x02 \x01(\x03\x12\x11\n\tEndOffset\x18\x03 \x01(\x03\x12\x14\n\x0c\x43lientOffset\x18\x04 \x01(\x03\x12\x18\n\x10WriteTimestampMS\x18\x05 \x01(\x03\x12\x19\n\x11\x43reateTimestampMS\x18\x06 \x01(\x03\x12\x34\n\tErrorCode\x18\x07 \x01(\x0e\x32!.NPersQueue.NErrorCode.EErrorCode\x12\x13\n\x0b\x45rrorReason\x18\x08 \x01(\t\x12\x18\n\x10\x43lientReadOffset\x18\t \x01(\x03\x12\x1c\n\x14ReadWriteTimestampMS\x18\n \x01(\x03\x12\x1d\n\x15ReadCreateTimestampMS\x18\x0b \x01(\x03\x12 \n\x18WriteTimestampEstimateMS\x18\x0c \x01(\x04\";\n\x07TStatus\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\x12\x1e\n\x16GetStatForAllConsumers\x18\x02 \x01(\x08\"`\n\x0fTClientPosition\x12\x0e\n\x06Offset\x18\x01 \x01(\x03\x12\x0c\n\x04Size\x18\x02 \x01(\x04\x12\x16\n\x0eWriteTimestamp\x18\x03 \x01(\x04\x12\x17\n\x0f\x43reateTimestamp\x18\x04 \x01(\x04\"\xdc\x01\n\x0bTClientInfo\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\x12\x31\n\rWritePosition\x18\x02 \x01(\x0b\x32\x1a.NKikimrPQ.TClientPosition\x12\x30\n\x0cReadPosition\x18\x03 \x01(\x0b\x32\x1a.NKikimrPQ.TClientPosition\x12\x12\n\nWriteLagMs\x18\x04 \x01(\x04\x12\x11\n\tReadLagMs\x18\x05 \x01(\x04\x12\x1b\n\x13LastReadTimestampMs\x18\x08 \x01(\x04\x12\x12\n\nTotalLagMs\x18\t \x01(\x04\"\x99\x0b\n\x0fTStatusResponse\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12:\n\nPartResult\x18\x02 \x03(\x0b\x32&.NKikimrPQ.TStatusResponse.TPartResult\x1a\x65\n\rTErrorMessage\x12\x11\n\tTimestamp\x18\x01 \x01(\x04\x12\x30\n\x07Service\x18\x02 \x01(\x0e\x32\x1f.NKikimrServices.EServiceKikimr\x12\x0f\n\x07Message\x18\x03 \x01(\t\x1a\x93\x07\n\x0bTPartResult\x12\x11\n\tPartition\x18\x01 \x01(\x05\x12\x32\n\x06Status\x18\x02 \x01(\x0e\x32\".NKikimrPQ.TStatusResponse.EStatus\x12\x1f\n\x17LastInitDurationSeconds\x18\x03 \x01(\x05\x12\x19\n\x11\x43reationTimestamp\x18\x04 \x01(\x05\x12\x10\n\x08GapCount\x18\x05 \x01(\x05\x12\x0f\n\x07GapSize\x18\x06 \x01(\x03\x12\x1b\n\x13\x41vgWriteSpeedPerSec\x18\x07 \x01(\x03\x12\x1b\n\x13\x41vgWriteSpeedPerMin\x18\x08 \x01(\x03\x12\x1c\n\x14\x41vgWriteSpeedPerHour\x18\t \x01(\x03\x12\x1b\n\x13\x41vgWriteSpeedPerDay\x18\n \x01(\x03\x12\x1a\n\x12\x41vgReadSpeedPerSec\x18\x0b \x01(\x03\x12\x1a\n\x12\x41vgReadSpeedPerMin\x18\x0c \x01(\x03\x12\x1b\n\x13\x41vgReadSpeedPerHour\x18\r \x01(\x03\x12\x1a\n\x12\x41vgReadSpeedPerDay\x18\x0e \x01(\x03\x12\x16\n\x0eReadBytesQuota\x18\x0f \x01(\x03\x12\x17\n\x0fWriteBytesQuota\x18\x10 \x01(\x03\x12\x15\n\rPartitionSize\x18\x11 \x01(\x03\x12(\n\x08LagsInfo\x18\x12 \x01(\x0b\x32\x16.NKikimrPQ.TClientInfo\x12\x13\n\x0bStartOffset\x18\x13 \x01(\x03\x12\x11\n\tEndOffset\x18\x14 \x01(\x03\x12\x1c\n\x14LastWriteTimestampMs\x18\x15 \x01(\x03\x12\x12\n\nWriteLagMs\x18\x16 \x01(\x03\x12\x1b\n\x13\x41vgQuotaSpeedPerSec\x18\x17 \x01(\x03\x12\x1b\n\x13\x41vgQuotaSpeedPerMin\x18\x18 \x01(\x03\x12\x1c\n\x14\x41vgQuotaSpeedPerHour\x18\x19 \x01(\x03\x12\x1b\n\x13\x41vgQuotaSpeedPerDay\x18\x1a \x01(\x03\x12\x15\n\rSourceIdCount\x18\x1b \x01(\x03\x12\"\n\x1aSourceIdRetentionPeriodSec\x18\x1c \x01(\x03\x12\x38\n\x06\x45rrors\x18\x1d \x03(\x0b\x32(.NKikimrPQ.TStatusResponse.TErrorMessage\x12\x42\n\x0e\x43onsumerResult\x18\x1e \x03(\x0b\x32*.NKikimrPQ.TStatusResponse.TConsumerResult\x1a\xbc\x01\n\x0fTConsumerResult\x12\x10\n\x08\x43onsumer\x18\x01 \x01(\t\x12\x1a\n\x12\x41vgReadSpeedPerMin\x18\x02 \x01(\x03\x12\x1b\n\x13\x41vgReadSpeedPerHour\x18\x03 \x01(\x03\x12\x1a\n\x12\x41vgReadSpeedPerDay\x18\x04 \x01(\x03\x12\x12\n\nWriteLagMs\x18\x05 \x01(\x04\x12\x11\n\tReadLagMs\x18\x06 \x01(\x04\x12\x1b\n\x13LastReadTimestampMs\x18\x07 \x01(\x04\"|\n\x07\x45Status\x12\r\n\tSTATUS_OK\x10\x00\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x01\x12\x17\n\x13STATUS_INITIALIZING\x10\x02\x12\x1c\n\x18STATUS_PARTITION_IS_FULL\x10\x03\x12\x17\n\x13STATUS_DISK_IS_FULL\x10\x04\"\x8d\x01\n\x0cTHasDataInfo\x12\x11\n\tPartition\x18\x01 \x01(\x05\x12\x0e\n\x06Offset\x18\x02 \x01(\x04\x12\x10\n\x08\x44\x65\x61\x64line\x18\x03 \x01(\x04\x12&\n\x06Sender\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x0e\n\x06\x43ookie\x18\x05 \x01(\x04\x12\x10\n\x08\x43lientId\x18\x06 \x01(\t\"l\n\x14THasDataInfoResponse\x12\x11\n\tEndOffset\x18\x01 \x01(\x04\x12\x0e\n\x06\x43ookie\x18\x02 \x01(\x04\x12\x0f\n\x07SizeLag\x18\x03 \x01(\x04\x12 \n\x18WriteTimestampEstimateMS\x18\x04 \x01(\x04\"\xde\x01\n\x0cTBatchHeader\x12\x0e\n\x06Offset\x18\x01 \x01(\x04\x12\x0e\n\x06PartNo\x18\x02 \x01(\r\x12\r\n\x05\x43ount\x18\x03 \x01(\r\x12\x1a\n\x12InternalPartsCount\x18\x04 \x01(\r\x12\x14\n\x0cUnpackedSize\x18\x05 \x01(\r\x12\x13\n\x0bPayloadSize\x18\x06 \x01(\r\x12\x0e\n\x06\x46ormat\x18\x07 \x01(\r\x12\x12\n\nHasKinesis\x18\x08 \x01(\x08\"4\n\x0e\x45PayloadFormat\x12\x11\n\rEUncompressed\x10\x00\x12\x0f\n\x0b\x45\x43ompressed\x10\x01\"\x83\x01\n\tTUserInfo\x12\x0e\n\x06Offset\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12\x0c\n\x04Step\x18\x03 \x01(\r\x12\x0f\n\x07Session\x18\x04 \x01(\t\x12\x17\n\x0fOffsetRewindSum\x18\x05 \x01(\x04\x12\x1a\n\x12ReadRuleGeneration\x18\x06 \x01(\x04\"*\n\x14TPartitionClientInfo\x12\x12\n\nPartitions\x18\x01 \x03(\x05\"\x97\x01\n\x13TClientInfoResponse\x12\x11\n\tPartition\x18\x01 \x01(\x05\x12\x13\n\x0bStartOffset\x18\x02 \x01(\x04\x12\x11\n\tEndOffset\x18\x03 \x01(\x04\x12\x19\n\x11ResponseTimestamp\x18\x04 \x01(\x04\x12*\n\nClientInfo\x18\x05 \x03(\x0b\x32\x16.NKikimrPQ.TClientInfo\"\xb0\x01\n\x19TPQClusterDiscoveryConfig\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12.\n\"TimedCountersUpdateIntervalSeconds\x18\x02 \x01(\r:\x02\x31\x35\x12\x34\n\x0c\x43loudNetData\x18\x03 \x01(\x0b\x32\x1e.NKikimrNetClassifier.TNetData\x12\x1c\n\x14RequestInflightLimit\x18\x04 \x01(\x04\"f\n\rTYdsNextToken\x12\x19\n\x11\x43reationTimestamp\x18\x01 \x02(\x04\x12\x12\n\nMaxResults\x18\x02 \x02(\r\x12\x13\n\x0b\x41lreadyRead\x18\x03 \x02(\r\x12\x11\n\tStreamArn\x18\x04 \x02(\t\"\xfd\x01\n\x11TYdsShardIterator\x12\x12\n\nStreamName\x18\x01 \x02(\t\x12\x11\n\tStreamArn\x18\x02 \x02(\t\x12\x0f\n\x07ShardId\x18\x03 \x02(\r\x12\x17\n\x0fReadTimestampMs\x18\x04 \x02(\x04\x12\x16\n\x0eSequenceNumber\x18\x05 \x02(\x04\x12\x1b\n\x13\x43reationTimestampMs\x18\x06 \x02(\x04\x12\x35\n\x04Kind\x18\x07 \x01(\x0e\x32\'.NKikimrPQ.TYdsShardIterator.ETopicKind\"+\n\nETopicKind\x12\x0f\n\x0bKIND_COMMON\x10\x00\x12\x0c\n\x08KIND_CDC\x10\x01\"f\n\x13TPartitionOperation\x12\x13\n\x0bPartitionId\x18\x01 \x02(\x04\x12\r\n\x05\x42\x65gin\x18\x02 \x01(\x04\x12\x0b\n\x03\x45nd\x18\x03 \x01(\x04\x12\x10\n\x08\x43onsumer\x18\x04 \x01(\t\x12\x0c\n\x04Path\x18\x05 \x02(\t\"\x90\x02\n\x0fTKqpTransaction\x12\x32\n\nOperations\x18\x01 \x03(\x0b\x32\x1e.NKikimrPQ.TPartitionOperation\x12/\n\x02Op\x18\x02 \x02(\x0e\x32#.NKikimrPQ.TKqpTransaction.ELocksOp\x12\x15\n\rSendingShards\x18\x03 \x03(\x04\x12\x17\n\x0fReceivingShards\x18\x04 \x03(\x04\x12\x11\n\tImmediate\x18\x05 \x02(\x08\x12\x10\n\x08LockTxId\x18\x06 \x01(\x06\"C\n\x08\x45LocksOp\x12\x0f\n\x0bUnspecified\x10\x00\x12\x0c\n\x08Validate\x10\x01\x12\n\n\x06\x43ommit\x10\x02\x12\x0c\n\x08Rollback\x10\x03\"y\n\x15TEvProposeTransaction\x12&\n\x06Source\x18\x01 \x02(\x0b\x32\x16.NActorsProto.TActorId\x12*\n\x06TxBody\x18\x02 \x02(\x0b\x32\x1a.NKikimrPQ.TKqpTransaction\x12\x0c\n\x04TxId\x18\x03 \x02(\x04\"\xac\x02\n\x1bTEvProposeTransactionResult\x12\x0e\n\x06Origin\x18\x01 \x02(\x04\x12>\n\x06Status\x18\x02 \x02(\x0e\x32..NKikimrPQ.TEvProposeTransactionResult.EStatus\x12\x0c\n\x04TxId\x18\x03 \x02(\x04\x12\x0f\n\x07MinStep\x18\x04 \x01(\x04\x12\x0f\n\x07MaxStep\x18\x06 \x01(\x04\x12\x0c\n\x04Step\x18\x07 \x01(\x04\"\x7f\n\x07\x45Status\x12\x0c\n\x08PREPARED\x10\x01\x12\x0c\n\x08\x43OMPLETE\x10\x02\x12\x0b\n\x07\x41\x42ORTED\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\x10\n\x0cLOCKS_BROKEN\x10\x05\x12\r\n\tCANCELLED\x10\x06\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x07\x12\x0e\n\nOVERLOADED\x10\x08\",\n\x1cTEvCancelTransactionProposal\x12\x0c\n\x04TxId\x18\x01 \x02(\x04*\'\n\nEOperation\x12\x0b\n\x07READ_OP\x10\x01\x12\x0c\n\x08WRITE_OP\x10\x02*/\n\x07\x45\x41\x63\x63\x65ss\x12\x0b\n\x07\x41LLOWED\x10\x01\x12\n\n\x06\x44\x45NIED\x10\x02\x12\x0b\n\x07UNKNOWN\x10\x03*)\n\x0c\x45TabletState\x12\x0b\n\x07\x45Normal\x10\x00\x12\x0c\n\x08\x45\x44ropped\x10\x01*Q\n\x07\x45Status\x12\x06\n\x02OK\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\x15\n\x11\x45RROR_BAD_VERSION\x10\x02\x12\x1c\n\x18\x45RROR_UPDATE_IN_PROGRESS\x10\x03\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.pqconfig_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TPQCONFIG.fields_by_name['MetaCacheTimeoutSec']._options = None
  _TPQCONFIG.fields_by_name['MetaCacheTimeoutSec']._serialized_options = b'\030\001'
  _TPQCONFIG.fields_by_name['MetaCacheRefreshIntervalMilliSeconds']._options = None
  _TPQCONFIG.fields_by_name['MetaCacheRefreshIntervalMilliSeconds']._serialized_options = b'\030\001'
  _TPQCONFIG.fields_by_name['MetaCacheSkipVersionCheck']._options = None
  _TPQCONFIG.fields_by_name['MetaCacheSkipVersionCheck']._serialized_options = b'\030\001'
  _EOPERATION._serialized_start=15140
  _EOPERATION._serialized_end=15179
  _EACCESS._serialized_start=15181
  _EACCESS._serialized_end=15228
  _ETABLETSTATE._serialized_start=15230
  _ETABLETSTATE._serialized_end=15271
  _ESTATUS._serialized_start=15273
  _ESTATUS._serialized_end=15354
  _TPARTITIONMETA._serialized_start=392
  _TPARTITIONMETA._serialized_end=448
  _TPARTITIONTXMETA._serialized_start=450
  _TPARTITIONTXMETA._serialized_end=500
  _TPQCONFIG._serialized_start=503
  _TPQCONFIG._serialized_end=4300
  _TPQCONFIG_TQUOTINGCONFIG._serialized_start=2815
  _TPQCONFIG_TQUOTINGCONFIG._serialized_end=3233
  _TPQCONFIG_TQUOTINGCONFIG_ELIMITEDENTITY._serialized_start=3154
  _TPQCONFIG_TQUOTINGCONFIG_ELIMITEDENTITY._serialized_end=3233
  _TPQCONFIG_TPQLIBSETTINGS._serialized_start=3235
  _TPQCONFIG_TPQLIBSETTINGS._serialized_end=3335
  _TPQCONFIG_TMIRRORCONFIG._serialized_start=3337
  _TPQCONFIG_TMIRRORCONFIG._serialized_end=3435
  _TPQCONFIG_TVALIDRETENTIONLIMIT._serialized_start=3438
  _TPQCONFIG_TVALIDRETENTIONLIMIT._serialized_end=3570
  _TPQCONFIG_TREADMETERINGCONFIG._serialized_start=3573
  _TPQCONFIG_TREADMETERINGCONFIG._serialized_end=3772
  _TPQCONFIG_TREADMETERINGCONFIG_TPRICING._serialized_start=3739
  _TPQCONFIG_TREADMETERINGCONFIG_TPRICING._serialized_end=3772
  _TPQCONFIG_TBILLINGMETERINGCONFIG._serialized_start=3775
  _TPQCONFIG_TBILLINGMETERINGCONFIG._serialized_end=3909
  _TPQCONFIG_TCLIENTSERVICETYPE._serialized_start=3912
  _TPQCONFIG_TCLIENTSERVICETYPE._serialized_end=4047
  _TPQCONFIG_TPQDISCOVERYCONFIG._serialized_start=4050
  _TPQCONFIG_TPQDISCOVERYCONFIG._serialized_end=4250
  _TPQCONFIG_TMOVETOPICACTORCONFIG._serialized_start=4252
  _TPQCONFIG_TMOVETOPICACTORCONFIG._serialized_end=4300
  _TCHANNELPROFILE._serialized_start=4303
  _TCHANNELPROFILE._serialized_end=4436
  _TMIRRORPARTITIONCONFIG._serialized_start=4439
  _TMIRRORPARTITIONCONFIG._serialized_end=4935
  _TMIRRORPARTITIONCONFIG_TCREDENTIALS._serialized_start=4722
  _TMIRRORPARTITIONCONFIG_TCREDENTIALS._serialized_end=4935
  _TMIRRORPARTITIONCONFIG_TCREDENTIALS_IAMCREDENTIALS._serialized_start=4859
  _TMIRRORPARTITIONCONFIG_TCREDENTIALS_IAMCREDENTIALS._serialized_end=4920
  _TPARTITIONCONFIG._serialized_start=4938
  _TPARTITIONCONFIG._serialized_end=5702
  _TPARTITIONCONFIG_TREADQUOTA._serialized_start=5622
  _TPARTITIONCONFIG_TREADQUOTA._serialized_end=5702
  _TPARTITIONKEYRANGE._serialized_start=5704
  _TPARTITIONKEYRANGE._serialized_end=5760
  _TMESSAGEGROUP._serialized_start=5762
  _TMESSAGEGROUP._serialized_end=5838
  _TPQTABLETCONFIG._serialized_start=5841
  _TPQTABLETCONFIG._serialized_end=7131
  _TPQTABLETCONFIG_TCODECS._serialized_start=6826
  _TPQTABLETCONFIG_TCODECS._serialized_end=6864
  _TPQTABLETCONFIG_TKEYCOMPONENTSCHEMA._serialized_start=6866
  _TPQTABLETCONFIG_TKEYCOMPONENTSCHEMA._serialized_end=6960
  _TPQTABLETCONFIG_TPARTITION._serialized_start=6962
  _TPQTABLETCONFIG_TPARTITION._serialized_end=7044
  _TPQTABLETCONFIG_EMETERINGMODE._serialized_start=7046
  _TPQTABLETCONFIG_EMETERINGMODE._serialized_end=7131
  _TMESSAGEGROUPINFO._serialized_start=7134
  _TMESSAGEGROUPINFO._serialized_end=7435
  _TMESSAGEGROUPINFO_ESTATE._serialized_start=7354
  _TMESSAGEGROUPINFO_ESTATE._serialized_end=7435
  _TBOOTSTRAPCONFIG._serialized_start=7437
  _TBOOTSTRAPCONFIG._serialized_end=7512
  _TUPDATECONFIG._serialized_start=7515
  _TUPDATECONFIG._serialized_end=7648
  _TUPDATEBALANCERCONFIG._serialized_start=7651
  _TUPDATEBALANCERCONFIG._serialized_end=8152
  _TUPDATEBALANCERCONFIG_TPARTITION._serialized_start=8031
  _TUPDATEBALANCERCONFIG_TPARTITION._serialized_end=8095
  _TUPDATEBALANCERCONFIG_TTABLET._serialized_start=8097
  _TUPDATEBALANCERCONFIG_TTABLET._serialized_end=8152
  _TDESCRIBE._serialized_start=8154
  _TDESCRIBE._serialized_end=8165
  _TDESCRIBERESPONSE._serialized_start=8168
  _TDESCRIBERESPONSE._serialized_end=8480
  _TDESCRIBERESPONSE_TPARTITION._serialized_start=8031
  _TDESCRIBERESPONSE_TPARTITION._serialized_end=8080
  _TCHECKACL._serialized_start=8482
  _TCHECKACL._serialized_end=8609
  _TCHECKACLRESPONSE._serialized_start=8611
  _TCHECKACLRESPONSE._serialized_end=8710
  _TGETPARTITIONIDFORWRITE._serialized_start=8712
  _TGETPARTITIONIDFORWRITE._serialized_end=8737
  _TGETPARTITIONIDFORWRITERESPONSE._serialized_start=8739
  _TGETPARTITIONIDFORWRITERESPONSE._serialized_end=8793
  _TREGISTERREADSESSION._serialized_start=8796
  _TREGISTERREADSESSION._serialized_end=8933
  _TGETREADSESSIONSINFO._serialized_start=8935
  _TGETREADSESSIONSINFO._serialized_end=8975
  _TREADSESSIONSTATUS._serialized_start=8977
  _TREADSESSIONSTATUS._serialized_end=8997
  _TREADSESSIONSTATUSRESPONSE._serialized_start=9000
  _TREADSESSIONSTATUSRESPONSE._serialized_end=9340
  _TREADSESSIONSTATUSRESPONSE_TPARTITIONSTATUS._serialized_start=9183
  _TREADSESSIONSTATUSRESPONSE_TPARTITIONSTATUS._serialized_end=9340
  _TREADSESSIONSINFORESPONSE._serialized_start=9343
  _TREADSESSIONSINFORESPONSE._serialized_end=9760
  _TREADSESSIONSINFORESPONSE_TPARTITIONINFO._serialized_start=9544
  _TREADSESSIONSINFORESPONSE_TPARTITIONINFO._serialized_end=9677
  _TREADSESSIONSINFORESPONSE_TREADSESSIONINFO._serialized_start=9679
  _TREADSESSIONSINFORESPONSE_TREADSESSIONINFO._serialized_end=9760
  _TLOCKPARTITION._serialized_start=9763
  _TLOCKPARTITION._serialized_end=9958
  _TRELEASEPARTITION._serialized_start=9961
  _TRELEASEPARTITION._serialized_end=10138
  _TPARTITIONRELEASED._serialized_start=10141
  _TPARTITIONRELEASED._serialized_end=10274
  _TDROPTABLET._serialized_start=10276
  _TDROPTABLET._serialized_end=10352
  _TDROPTABLETRESULT._serialized_start=10355
  _TDROPTABLETRESULT._serialized_end=10496
  _TTABLETSTATE._serialized_start=10498
  _TTABLETSTATE._serialized_end=10552
  _TUPDATECONFIGRESPONSE._serialized_start=10554
  _TUPDATECONFIGRESPONSE._serialized_end=10643
  _TOFFSETS._serialized_start=10645
  _TOFFSETS._serialized_end=10673
  _TOFFSETSRESPONSE._serialized_start=10676
  _TOFFSETSRESPONSE._serialized_end=11119
  _TOFFSETSRESPONSE_TPARTRESULT._serialized_start=10776
  _TOFFSETSRESPONSE_TPARTRESULT._serialized_end=11119
  _TSTATUS._serialized_start=11121
  _TSTATUS._serialized_end=11180
  _TCLIENTPOSITION._serialized_start=11182
  _TCLIENTPOSITION._serialized_end=11278
  _TCLIENTINFO._serialized_start=11281
  _TCLIENTINFO._serialized_end=11501
  _TSTATUSRESPONSE._serialized_start=11504
  _TSTATUSRESPONSE._serialized_end=12937
  _TSTATUSRESPONSE_TERRORMESSAGE._serialized_start=11601
  _TSTATUSRESPONSE_TERRORMESSAGE._serialized_end=11702
  _TSTATUSRESPONSE_TPARTRESULT._serialized_start=11705
  _TSTATUSRESPONSE_TPARTRESULT._serialized_end=12620
  _TSTATUSRESPONSE_TCONSUMERRESULT._serialized_start=12623
  _TSTATUSRESPONSE_TCONSUMERRESULT._serialized_end=12811
  _TSTATUSRESPONSE_ESTATUS._serialized_start=12813
  _TSTATUSRESPONSE_ESTATUS._serialized_end=12937
  _THASDATAINFO._serialized_start=12940
  _THASDATAINFO._serialized_end=13081
  _THASDATAINFORESPONSE._serialized_start=13083
  _THASDATAINFORESPONSE._serialized_end=13191
  _TBATCHHEADER._serialized_start=13194
  _TBATCHHEADER._serialized_end=13416
  _TBATCHHEADER_EPAYLOADFORMAT._serialized_start=13364
  _TBATCHHEADER_EPAYLOADFORMAT._serialized_end=13416
  _TUSERINFO._serialized_start=13419
  _TUSERINFO._serialized_end=13550
  _TPARTITIONCLIENTINFO._serialized_start=13552
  _TPARTITIONCLIENTINFO._serialized_end=13594
  _TCLIENTINFORESPONSE._serialized_start=13597
  _TCLIENTINFORESPONSE._serialized_end=13748
  _TPQCLUSTERDISCOVERYCONFIG._serialized_start=13751
  _TPQCLUSTERDISCOVERYCONFIG._serialized_end=13927
  _TYDSNEXTTOKEN._serialized_start=13929
  _TYDSNEXTTOKEN._serialized_end=14031
  _TYDSSHARDITERATOR._serialized_start=14034
  _TYDSSHARDITERATOR._serialized_end=14287
  _TYDSSHARDITERATOR_ETOPICKIND._serialized_start=14244
  _TYDSSHARDITERATOR_ETOPICKIND._serialized_end=14287
  _TPARTITIONOPERATION._serialized_start=14289
  _TPARTITIONOPERATION._serialized_end=14391
  _TKQPTRANSACTION._serialized_start=14394
  _TKQPTRANSACTION._serialized_end=14666
  _TKQPTRANSACTION_ELOCKSOP._serialized_start=14599
  _TKQPTRANSACTION_ELOCKSOP._serialized_end=14666
  _TEVPROPOSETRANSACTION._serialized_start=14668
  _TEVPROPOSETRANSACTION._serialized_end=14789
  _TEVPROPOSETRANSACTIONRESULT._serialized_start=14792
  _TEVPROPOSETRANSACTIONRESULT._serialized_end=15092
  _TEVPROPOSETRANSACTIONRESULT_ESTATUS._serialized_start=14965
  _TEVPROPOSETRANSACTIONRESULT_ESTATUS._serialized_end=15092
  _TEVCANCELTRANSACTIONPROPOSAL._serialized_start=15094
  _TEVCANCELTRANSACTIONPROPOSAL._serialized_end=15138
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/subdomains.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import bind_channel_storage_pool_pb2 as ydb_dot_core_dot_protos_dot_bind__channel__storage__pool__pb2
from ydb.public.api.protos import ydb_cms_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__cms__pb2
from ydb.library.login.protos import login_pb2 as ydb_dot_library_dot_login_dot_protos_dot_login__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n ydb/core/protos/subdomains.proto\x12\x11NKikimrSubDomains\x1a/ydb/core/protos/bind_channel_storage_pool.proto\x1a#ydb/public/api/protos/ydb_cms.proto\x1a$ydb/library/login/protos/login.proto\"1\n\nTDomainKey\x12\x13\n\x0bSchemeShard\x18\x01 \x01(\x06\x12\x0e\n\x06PathId\x18\x02 \x01(\x06\"\xd5\x03\n\x12TSubDomainSettings\x12\x16\n\x0ePlanResolution\x18\x01 \x01(\x04\x12\x14\n\x0c\x43oordinators\x18\x02 \x01(\x04\x12\x11\n\tMediators\x18\x03 \x01(\x04\x12\x0c\n\x04Name\x18\x04 \x01(\t\x12\"\n\x1aTimeCastBucketsPerMediator\x18\x05 \x01(\r\x12\x36\n\x0cStoragePools\x18\x06 \x03(\x0b\x32 .NKikimrStoragePool.TStoragePool\x12\"\n\x13\x45xternalSchemeShard\x18\x07 \x01(\x08:\x05\x66\x61lse\x12\x1b\n\x0c\x45xternalHive\x18\x08 \x01(\x08:\x05\x66\x61lse\x12\x39\n\x12ResourcesDomainKey\x18\t \x01(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\x12\'\n\x18\x45xternalSysViewProcessor\x18\n \x01(\x08:\x05\x66\x61lse\x12>\n\x14\x44\x65\x63laredSchemeQuotas\x18\x0b \x01(\x0b\x32 .NKikimrSubDomains.TSchemeQuotas\x12/\n\x0e\x44\x61tabaseQuotas\x18\x0c \x01(\x0b\x32\x17.Ydb.Cms.DatabaseQuotas\"\xc6\x01\n\x11TProcessingParams\x12\x0f\n\x07Version\x18\x01 \x01(\r\x12\x16\n\x0ePlanResolution\x18\x02 \x01(\x04\x12\x14\n\x0c\x43oordinators\x18\x03 \x03(\x06\x12\"\n\x1aTimeCastBucketsPerMediator\x18\x04 \x01(\x04\x12\x11\n\tMediators\x18\x05 \x03(\x06\x12\x13\n\x0bSchemeShard\x18\x06 \x01(\x06\x12\x0c\n\x04Hive\x18\x07 \x01(\x06\x12\x18\n\x10SysViewProcessor\x18\x08 \x01(\x06\"\x90\x01\n\x0fTDiskSpaceUsage\x12:\n\x06Tables\x18\x01 \x01(\x0b\x32*.NKikimrSubDomains.TDiskSpaceUsage.TTables\x1a\x41\n\x07TTables\x12\x11\n\tTotalSize\x18\x01 \x01(\x04\x12\x10\n\x08\x44\x61taSize\x18\x02 \x01(\x04\x12\x11\n\tIndexSize\x18\x03 \x01(\x04\")\n\x0cTDomainState\x12\x19\n\x11\x44iskQuotaExceeded\x18\x01 \x01(\x08\"\xd8\x05\n\x12TDomainDescription\x12 \n\x18SchemeShardId_Depricated\x18\x01 \x01(\x06\x12\x19\n\x11PathId_Depricated\x18\x02 \x01(\x06\x12>\n\x10ProcessingParams\x18\x03 \x01(\x0b\x32$.NKikimrSubDomains.TProcessingParams\x12\x30\n\tDomainKey\x18\x04 \x01(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\x12\x36\n\x0cStoragePools\x18\x05 \x03(\x0b\x32 .NKikimrStoragePool.TStoragePool\x12\x13\n\x0bPathsInside\x18\x06 \x01(\x04\x12\x12\n\nPathsLimit\x18\x07 \x01(\x04\x12\x14\n\x0cShardsInside\x18\x08 \x01(\x04\x12\x13\n\x0bShardsLimit\x18\t \x01(\x04\x12\x39\n\x12ResourcesDomainKey\x18\n \x01(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\x12:\n\x0e\x44iskSpaceUsage\x18\x0b \x01(\x0b\x32\".NKikimrSubDomains.TDiskSpaceUsage\x12>\n\x14\x44\x65\x63laredSchemeQuotas\x18\x0c \x01(\x0b\x32 .NKikimrSubDomains.TSchemeQuotas\x12\x1a\n\x12PQPartitionsInside\x18\r \x01(\x04\x12\x19\n\x11PQPartitionsLimit\x18\x0e \x01(\x04\x12/\n\x0e\x44\x61tabaseQuotas\x18\x0f \x01(\x0b\x32\x17.Ydb.Cms.DatabaseQuotas\x12\x34\n\x0b\x44omainState\x18\x10 \x01(\x0b\x32\x1f.NKikimrSubDomains.TDomainState\x12\x32\n\rSecurityState\x18\x14 \x01(\x0b\x32\x1b.NLoginProto.TSecurityState\"F\n\rTSchemeQuotas\x12\x35\n\x0cSchemeQuotas\x18\x01 \x03(\x0b\x32\x1f.NKikimrSubDomains.TSchemeQuota\"9\n\x0cTSchemeQuota\x12\x12\n\nBucketSize\x18\x01 \x01(\x01\x12\x15\n\rBucketSeconds\x18\x02 \x01(\x04')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.subdomains_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TDOMAINKEY._serialized_start=179
  _TDOMAINKEY._serialized_end=228
  _TSUBDOMAINSETTINGS._serialized_start=231
  _TSUBDOMAINSETTINGS._serialized_end=700
  _TPROCESSINGPARAMS._serialized_start=703
  _TPROCESSINGPARAMS._serialized_end=901
  _TDISKSPACEUSAGE._serialized_start=904
  _TDISKSPACEUSAGE._serialized_end=1048
  _TDISKSPACEUSAGE_TTABLES._serialized_start=983
  _TDISKSPACEUSAGE_TTABLES._serialized_end=1048
  _TDOMAINSTATE._serialized_start=1050
  _TDOMAINSTATE._serialized_end=1091
  _TDOMAINDESCRIPTION._serialized_start=1094
  _TDOMAINDESCRIPTION._serialized_end=1822
  _TSCHEMEQUOTAS._serialized_start=1824
  _TSCHEMEQUOTAS._serialized_end=1894
  _TSCHEMEQUOTA._serialized_start=1896
  _TSCHEMEQUOTA._serialized_end=1953
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_testshard.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ydb/core/protos/counters_testshard.proto\x12\x12NKikimr.NTestShard\x1a\x1eydb/core/protos/counters.proto*4\n\x13\x45\x43umulativeCounters\x12\x1d\n\x19\x43OUNTER_CUMULATIVE_IGNORE\x10\x00*\xb3\x01\n\x0f\x45SimpleCounters\x12\'\n\x12\x43OUNTER_MODE_WRITE\x10\x00\x1a\x0f\x82\xd6\x1b\x0b\n\tModeWrite\x12\x36\n\x1a\x43OUNTER_MODE_READ_VALIDATE\x10\x01\x1a\x16\x82\xd6\x1b\x12\n\x10ModeReadValidate\x12?\n!COUNTER_MODE_STATE_SERVER_CONNECT\x10\x02\x1a\x18\x82\xd6\x1b\x14\n\x12StateServerConnect*4\n\x13\x45PercentileCounters\x12\x1d\n\x19\x43OUNTER_PERCENTILE_IGNORE\x10\x00\x42%\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\tTestShard')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_testshard_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\tTestShard'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_MODE_WRITE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_MODE_WRITE"]._serialized_options = b'\202\326\033\013\n\tModeWrite'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_MODE_READ_VALIDATE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_MODE_READ_VALIDATE"]._serialized_options = b'\202\326\033\022\n\020ModeReadValidate'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_MODE_STATE_SERVER_CONNECT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_MODE_STATE_SERVER_CONNECT"]._serialized_options = b'\202\326\033\024\n\022StateServerConnect'
  _ECUMULATIVECOUNTERS._serialized_start=96
  _ECUMULATIVECOUNTERS._serialized_end=148
  _ESIMPLECOUNTERS._serialized_start=151
  _ESIMPLECOUNTERS._serialized_end=330
  _EPERCENTILECOUNTERS._serialized_start=332
  _EPERCENTILECOUNTERS._serialized_end=384
# @@protoc_insertion_point(module_scope)
